@@ -1,4 +1,5 @@
 <?php
+/* $Id: admin_handler.php,v 1.7.4.3 2005/11/29 15:28:25 cknudsen Exp $ */
 include_once 'includes/init.php';
 
 $error = "";
@@ -10,6 +11,12 @@ if ( ! $is_admin ) {
 if ( $error == "" ) {
   while ( list ( $key, $value ) = each ( $HTTP_POST_VARS ) ) {
     $setting = substr ( $key, 6 );
+    // validate key name.  should start with "admin_" and not include
+    // any unusual characters that might cause SQL injection
+    if ( ! preg_match ( '/admin_[A-Za-z0-9_]+$/', $key ) ) {
+      die_miserable_death ( 'Invalid admin setting name "' .
+        $key . '"' );
+    }
     if ( strlen ( $setting ) > 0 ) {
       $sql = "DELETE FROM webcal_config WHERE cal_setting = '$setting'";
       if ( ! dbi_query ( $sql ) ) {
