@@ -1,23 +1,30 @@
 <?php
 /*
- * $Id: edit_entry.php,v 1.71 2004/12/09 22:07:34 cknudsen Exp $
+ * $Id: edit_entry.php,v 1.91.2.1 2005/08/08 23:30:57 cknudsen Exp $
  *
  * Description:
- *	Presents page to edit/add an event
+ * Presents page to edit/add an event
  *
  * Notes:
- *	If htmlarea is installed, users can use WYSIWYG editing.
- *	SysAdmin must enable HTML for event full descriptions.
- *	The htmlarea files should be installed so that the htmlarea.php
- *	file is in ../includes/htmlarea/htmlarea.php
- *	The htmlarea code can be downloaded from:
- *		http://www.htmlarea.com
- *
+ * If htmlarea is installed, users can use WYSIWYG editing.
+ * SysAdmin must enable HTML for event full descriptions.
+ * The htmlarea files should be installed so that the htmlarea.php
+ * file is in ../includes/htmlarea/htmlarea.php
+ * The htmlarea code can be downloaded from:
+ *  http://www.htmlarea.com
+ * TODO
+ * This file will not pass XHTML validation with HTMLArea enabled
  */
 include_once 'includes/init.php';
 include_once 'includes/site_extras.php';
+
 load_user_categories ();
 
+// Default for using tabs is enabled
+if ( empty ( $EVENT_EDIT_TABS ) )
+  $EVENT_EDIT_TABS = 'Y'; // default
+$useTabs = ( $EVENT_EDIT_TABS == 'Y' );
+
 // make sure this is not a read-only calendar
 $can_edit = false;
 
@@ -54,7 +61,7 @@ if ( $readonly == 'Y' ) {
   }
   $sql = "SELECT cal_create_by, cal_date, cal_time, cal_mod_date, " .
     "cal_mod_time, cal_duration, cal_priority, cal_type, cal_access, " .
-    "cal_name, cal_description FROM webcal_entry WHERE cal_id = " . $id;
+    "cal_name, cal_description, cal_group_id FROM webcal_entry WHERE cal_id = " . $id;
   $res = dbi_query ( $sql );
   if ( $res ) {
     $row = dbi_fetch_row ( $res );
@@ -71,8 +78,9 @@ if ( $readonly == 'Y' ) {
     $month = ( $cal_date / 100 ) % 100;
     $day = $cal_date % 100;
     $time = $row[2];
-    if ( $time >= 0 ) { /* -1 = no time specified */
-      $time += $TZ_OFFSET * 10000;
+    // test for AllDay event, if so, don't adjust time
+    if ( $time > 0  || ( $time == 0 &&  $row[5] != 1440 ) ) { /* -1 = no time specified */
+      $time += ( ! empty ( $TZ_OFFSET )?$TZ_OFFSET : 0)  * 10000;
       if ( $time > 240000 ) {
         $time -= 240000;
         $gmt = mktime ( 3, 0, 0, $month, $day, $year );
@@ -83,8 +91,8 @@ if ( $readonly == 'Y' ) {
       } else if ( $time < 0 ) {
         $time += 240000;
         $gmt = mktime ( 3, 0, 0, $month, $day, $year );
-	$gmt -= $ONE_DAY;
-	$month = date ( "m", $gmt );
+        $gmt -= $ONE_DAY;
+        $month = date ( "m", $gmt );
         $day = date ( "d", $gmt );
         $year = date ( "Y", $gmt );
       }
@@ -97,12 +105,14 @@ if ( $readonly == 'Y' ) {
       $duration = $row[5];
     } else {
       $duration = "";
+      $hour = -1;
     }
     $priority = $row[6];
     $type = $row[7];
     $access = $row[8];
     $name = $row[9];
     $description = $row[10];
+    $parent = $row[11];
     // check for repeating event info...
     // but not if we are overriding a single entry of an already repeating
     // event... confusing, eh?
@@ -144,9 +154,9 @@ if ( $readonly == 'Y' ) {
   $res = dbi_query ( $sql );
   if ( $res ) {
     while ( $row = dbi_fetch_row ( $res ) ) {
-      if ( ( empty ( $is_secretary ) || ! $is_secretary )
-        || $login != $row[0] ) $participants[$row[0]] = 1;
+      $participants[$row[0]] = 1;
       if ($login == $row[0]) $cat_id = $row[1];
+      if ( ( $is_assistant  || $is_admin ) && $user == $row[0]) $cat_id = $row[1];
     }
   }
   if ( ! empty ( $allow_external_users ) && $allow_external_users == "Y" ) {
@@ -155,10 +165,13 @@ if ( $readonly == 'Y' ) {
 } else {
   // New event.
   $id = 0; // to avoid warnings below about use of undefined var
-  if ( empty ( $hour ) )
-    $time = -1;
-  else
+  // Anything other then testing for strlen breaks either hour=0 or no hour in URL
+  if ( strlen ( $hour ) ) {
     $time = $hour * 100;
+  } else {
+    $time = -1;
+    $hour = -1;
+  }
   if ( ! empty ( $defusers ) ) {
     $tmp_ar = explode ( ",", $defusers );
     for ( $i = 0; $i < count ( $tmp_ar ); $i++ ) {
@@ -186,7 +199,7 @@ if ( empty ( $rpt_type ) || ! $rpt_type )
   $rpt_type = "none";
 
 // avoid error for using undefined vars
-if ( empty ( $hour ) )
+if ( ! isset ( $hour ) )
   $hour = -1;
 if ( empty ( $duration ) )
   $duration = 0;
@@ -221,8 +234,12 @@ if ( ( empty ( $year ) || ! $year ) &&
 }
 if ( empty ( $thisyear ) )
   $thisdate = date ( "Ymd" );
-else
-  $thisdate = sprintf ( "%04d%02d%02d", $thisyear, $thismonth, $thisday );
+else {
+  $thisdate = sprintf ( "%04d%02d%02d",
+    empty ( $thisyear ) ? date ( "Y" ) : $thisyear,
+    empty ( $thismonth ) ? date ( "m" ) : $thismonth,
+    empty ( $thisday ) ? date ( "d" ) : $thisday );
+}
 if ( empty ( $cal_date ) || ! $cal_date )
   $cal_date = $thisdate;
 
@@ -231,17 +248,17 @@ if ( $allow_html_description == "Y" ){
   // If they have installed the htmlarea widget, make use of it
   $textareasize = 'rows="15" cols="50"';
   if ( file_exists ( "includes/htmlarea/htmlarea.php" ) ) {
-    $BodyX = 'onload="initEditor();timetype_handler()"';
+    $BodyX = 'onload="initEditor();timetype_handler();rpttype_handler()"';
     $INC = array ( 'htmlarea/htmlarea.php', 'js/edit_entry.php',
       'js/visible.php', 'htmlarea/core.php' );
   } else {
     // No htmlarea files found...
-    $BodyX = 'onload="timetype_handler()"';
+    $BodyX = 'onload="timetype_handler();rpttype_handler()"';
     $INC = array ( 'js/edit_entry.php', 'js/visible.php' );
   }
 } else {
   $textareasize = 'rows="5" cols="40"';
-  $BodyX = 'onload="timetype_handler()"';
+  $BodyX = 'onload="timetype_handler();rpttype_handler()"';
   $INC = array('js/edit_entry.php','js/visible.php');
 }
 
@@ -252,12 +269,12 @@ print_header ( $INC, '', $BodyX );
 <h2><?php if ( $id ) echo translate("Edit Entry"); else echo translate("Add Entry"); ?>&nbsp;<img src="help.gif" alt="<?php etranslate("Help")?>" class="help" onclick="window.open ( 'help_edit_entry.php<?php if ( empty ( $id ) ) echo "?add=1"; ?>', 'cal_help', 'dependent,menubar,scrollbars,height=400,width=400,innerHeight=420,outerWidth=420');" /></h2>
 
 <?php
-	if ( $can_edit ) {
+ if ( $can_edit ) {
 ?>
 <form action="edit_entry_handler.php" method="post" name="editentryform">
 
 <?php
-if ( ! empty ( $id ) && ( $copy != '1' ) ) echo "<input type=\"hidden\" name=\"id\" value=\"$id\" />\n";
+if ( ! empty ( $id ) && ( empty ( $copy ) || $copy != '1' ) ) echo "<input type=\"hidden\" name=\"id\" value=\"$id\" />\n";
 // we need an additional hidden input field
 echo "<input type=\"hidden\" name=\"entry_changed\" value=\"\" />\n";
 
@@ -270,64 +287,213 @@ if ( ! empty ( $override ) ) {
 if ( $is_assistant || $is_nonuser_admin || ! empty ( $user ) )
    echo "<input type=\"hidden\" name=\"user\" value=\"$user\" />\n";
 
+// if has cal_group_id was set, need to send parent = $parent
+if ( ! empty ( $parent ) )
+   echo "<input type=\"hidden\" name=\"parent\" value=\"$parent\" />\n";
+
 ?>
 
 <!-- TABS -->
+<?php if ( $useTabs ) { ?>
 <div id="tabs">
-	<span class="tabfor" id="tab_details"><a href="#tabdetails" onclick="return showTab('details')"><?php etranslate("Details") ?></a></span>
-	<span class="tabbak" id="tab_sched"><a href="#tabsched" onclick="return showTab('sched')"><?php etranslate("Scheduling") ?></a></span>
-	<span class="tabbak" id="tab_participants"><a href="#tabparticipants" onclick="return showTab('participants')"><?php etranslate("Participants") ?></a></span>
-	<span class="tabbak" id="tab_pete"><a href="#tabpete" onclick="return showTab('pete')"><?php etranslate("Repeat") ?></a></span>
+ <span class="tabfor" id="tab_details"><a href="#tabdetails" onclick="return showTab('details')"><?php etranslate("Details") ?></a></span>
+ <?php if ( $disable_participants_field != "Y" ) { ?>
+   <span class="tabbak" id="tab_participants"><a href="#tabparticipants" onclick="return showTab('participants')"><?php etranslate("Participants") ?></a></span>
+ <?php } ?> 
+ <?php if ( $disable_repeating_field != "Y" ) { ?>
+   <span class="tabbak" id="tab_pete"><a href="#tabpete" onclick="return showTab('pete')"><?php etranslate("Repeat") ?></a></span>
+ <?php } ?>
 </div>
+<?php } ?>
 
 <!-- TABS BODY -->
+<?php if ( $useTabs ) { ?>
 <div id="tabscontent">
-	<!-- DETAILS -->
-	<a name="tabdetails"></a>
-	<div id="tabscontent_details">
-		<table style="border-width:0px;">
-			<tr><td style="width:14%;" class="tooltip" title="<?php etooltip("brief-description-help")?>">
-				<label for="entry_brief"><?php etranslate("Brief Description")?>:</label></td><td>
-				<input type="text" name="name" id="entry_brief" size="25" value="<?php echo htmlspecialchars ( $name ); ?>" /></td><td style="width:35%;">
-			</td></tr>
-			<tr><td style="vertical-align:top;" class="tooltip" title="<?php etooltip("full-description-help")?>">
-				<label for="entry_full"><?php etranslate("Full Description")?>:</label></td><td>
-				<textarea name="description" id="entry_full" <?php echo $textareasize;?>><?php echo htmlspecialchars ( $description ); ?></textarea></td><td style="vertical-align:top;">
-				<?php if ( $disable_access_field != "Y" ) { ?>
-					<div class="tooltip" title="<?php etooltip("access-help")?>">
-						<label for="entry_access"><?php etranslate("Access")?>:</label>
-						<select name="access" id="entry_access">
-							<option value="P"<?php if ( $access == "P" || ! strlen ( $access ) ) echo " selected=\"selected\"";?>><?php etranslate("Public")?></option>
-							<option value="R"<?php if ( $access == "R" ) echo " selected=\"selected\"";?>><?php etranslate("Confidential")?></option>
-						</select>
-					</div><br />
-				<?php } ?>
-				<?php if ( ! empty ( $categories ) ) { ?>
-					<tr><td class="tooltip" title="<?php etooltip("category-help")?>">
-						<label for="entry_categories"><?php etranslate("Category")?>:&nbsp;</label></td><td>
-						<select name="cat_id" id="entry_categories">
-							<option value=""><?php etranslate("None")?></option>
-							<?php
-								foreach( $categories as $K => $V ){
-									echo "<option value=\"$K\"";
-									if ( $cat_id == $K ) echo " selected=\"selected\"";
-									echo ">$V</option>\n";
-								}
-							?>
-						</select>
-					</td></tr>
-				<?php } //end if (! empty ($categories)) ?>
-				<?php if ( $disable_priority_field != "Y" ) { ?>
-					<tr><td class="tooltip" title="<?php etooltip("priority-help")?>">
-						<label for="entry_prio"><?php etranslate("Priority")?>:&nbsp;</label></td><td>
-						<select name="priority" id="entry_prio">
-							<option value="1"<?php if ( $priority == 1 ) echo " selected=\"selected\"";?>><?php etranslate("Low")?></option>
-							<option value="2"<?php if ( $priority == 2 || $priority == 0 ) echo " selected=\"selected\"";?>><?php etranslate("Medium")?></option>
-							<option value="3"<?php if ( $priority == 3 ) echo " selected=\"selected\"";?>><?php etranslate("High")?></option>
-						</select>
-					</td></tr>
-				<?php } ?>
-			</td></tr>
+ <!-- DETAILS -->
+ <a name="tabdetails"></a>
+ <div id="tabscontent_details">
+<?php } ?>
+  <table style="border-width:0px;">
+   <tr><td style="width:14%;" class="tooltip" title="<?php etooltip("brief-description-help")?>">
+    <label for="entry_brief"><?php etranslate("Brief Description")?>:</label></td><td>
+    <input type="text" name="name" id="entry_brief" size="25" value="<?php 
+     echo htmlspecialchars ( $name );
+    ?>" /></td><td style="width:35%;">
+   </td></tr>
+   <tr><td style="vertical-align:top;" class="tooltip" title="<?php etooltip("full-description-help")?>">
+    <label for="entry_full"><?php etranslate("Full Description")?>:</label></td><td>
+    <textarea name="description" id="entry_full" <?php
+     echo $textareasize;
+    ?>><?php
+     echo htmlspecialchars ( $description );
+    ?></textarea></td><td style="vertical-align:top;">
+
+<?php if (( ! empty ( $categories ) ) || ( $disable_access_field != "Y" ) || 
+         ( $disable_priority_field != "Y" ) ){ // new table for extra fields ?>
+    <table>
+<?php } ?>
+<?php if ( $disable_access_field != "Y" ) { ?>
+      <tr><td class="tooltip" title="<?php etooltip("access-help")?>">
+       <label for="entry_access"><?php etranslate("Access")?>:</label></td><td>
+       <select name="access" id="entry_access">
+        <option value="P"<?php if ( $access == "P" || ! strlen ( $access ) ) echo " selected=\"selected\"";?>><?php etranslate("Public")?></option>
+        <option value="R"<?php if ( $access == "R" ) echo " selected=\"selected\"";?>><?php etranslate("Confidential")?></option>
+       </select>
+       </td></tr>
+<?php } ?>
+<?php if ( $disable_priority_field != "Y" ) { ?>
+     <tr><td class="tooltip" title="<?php etooltip("priority-help")?>">
+      <label for="entry_prio"><?php etranslate("Priority")?>:&nbsp;</label></td><td>
+      <select name="priority" id="entry_prio">
+       <option value="1"<?php if ( $priority == 1 ) echo " selected=\"selected\"";?>><?php etranslate("Low")?></option>
+       <option value="2"<?php if ( $priority == 2 || $priority == 0 ) echo " selected=\"selected\"";?>><?php etranslate("Medium")?></option>
+       <option value="3"<?php if ( $priority == 3 ) echo " selected=\"selected\"";?>><?php etranslate("High")?></option>
+      </select>
+     </td></tr>
+<?php } ?>
+<?php if ( ! empty ( $categories ) ) { ?>
+     <tr><td class="tooltip" title="<?php etooltip("category-help")?>">
+      <label for="entry_categories"><?php etranslate("Category")?>:&nbsp;</label></td><td>
+      <select name="cat_id" id="entry_categories">
+       <option value=""><?php etranslate("None")?></option>
+     <?php
+      foreach( $categories as $K => $V ){
+       echo "       <option value=\"$K\"";
+       if ( $cat_id == $K ) echo " selected=\"selected\"";
+       echo ">$V</option>\n";
+      }
+     ?>
+      </select>
+     </td></tr>
+<?php } //end if (! empty ($categories)) ?>
+<?php if (( ! empty ( $categories ) ) || ( $disable_access_field != "Y" ) || 
+         ( $disable_priority_field != "Y" ) ){ // end the table ?>
+   </table>
+    
+<?php } ?>
+  </td></tr>
+  <tr><td class="tooltip" title="<?php etooltip("date-help")?>">
+   <?php etranslate("Date")?>:</td><td colspan="2">
+   <?php
+    print_date_selection ( "", $cal_date );
+   ?>
+  </td></tr>
+  <tr><td>&nbsp;</td><td colspan="2">
+   <select name="timetype" onchange="timetype_handler()">
+    <option value="U" <?php if ( $allday != "Y" && $hour == -1 ) echo " selected=\"selected\""?>><?php etranslate("Untimed event"); ?></option>
+    <option value="T" <?php if ( $allday != "Y" && $hour >= 0 ) echo " selected=\"selected\""?>><?php etranslate("Timed event"); ?></option>
+    <option value="A" <?php if ( $allday == "Y" ) echo " selected=\"selected\""?>><?php etranslate("All day event"); ?></option>
+   </select>
+  </td></tr>
+  <tr id="timeentrystart"><td class="tooltip" title="<?php etooltip("time-help")?>">
+   <?php echo translate("Time") . ":"; ?></td><td colspan="2">
+<?php
+$h12 = $hour;
+$amsel = " checked=\"checked\""; $pmsel = "";
+if ( $TIME_FORMAT == "12" ) {
+  if ( $h12 < 12 ) {
+    $amsel = " checked=\"checked\""; $pmsel = "";
+  } else {
+    $amsel = ""; $pmsel = " checked=\"checked\"";
+  }
+  $h12 %= 12;
+  if ( $h12 == 0 ) $h12 = 12;
+}
+if ( $time < 0 )
+  $h12 = "";
+?>
+   <input type="text" name="hour" size="2" value="<?php 
+    if ( $time >= 0 && $allday != 'Y' ) echo $h12;
+   ?>" maxlength="2" />:<input type="text" name="minute" size="2" value="<?php 
+    if ( $time >= 0 && $allday != "Y" ) printf ( "%02d", $minute );
+   ?>" maxlength="2" />
+<?php
+if ( $TIME_FORMAT == "12" ) {
+  echo "<label><input type=\"radio\" name=\"ampm\" value=\"am\" $amsel />&nbsp;" .
+    translate("am") . "</label>\n";
+  echo "<label><input type=\"radio\" name=\"ampm\" value=\"pm\" $pmsel />&nbsp;" .
+    translate("pm") . "</label>\n";
+}
+?>
+
+<?php
+  $dur_h = (int)( $duration / 60 );
+  $dur_m = $duration - ( $dur_h * 60 );
+
+if ($GLOBALS['TIMED_EVT_LEN'] != 'E') { ?>
+   </td></tr>
+  <tr id="timeentryduration"><td>
+  <span class="tooltip" title="<?php 
+   etooltip("duration-help")
+  ?>"><?php 
+   etranslate("Duration")
+  ?>:&nbsp;</span></td><td colspan="2">
+  <input type="text" name="duration_h" id="duration_h" size="2" maxlength="2" value="<?php 
+   if ( $allday != "Y" ) printf ( "%d", $dur_h );
+  ?>" />:<input type="text" name="duration_m" id="duration_m" size="2" maxlength="2" value="<?php 
+   if ( $allday != "Y" ) 
+    printf ( "%02d", $dur_m );
+  ?>" />&nbsp;(<label for="duration_h"><?php 
+   echo translate("hours")
+  ?></label>: <label for="duration_m"><?php 
+   echo translate("minutes")
+  ?></label>)
+ </td></tr>
+<?php } else {
+if ( $id ) {
+  $t_h12 = $h12;
+  if ( $TIME_FORMAT == "12" ) {
+    // Convert to a twenty-four hour time scale
+    if ( !empty ( $amsel ) && $t_h12 == 12 )
+      $t_h12 = 0;
+    if ( !empty ( $pmsel ) && $t_h12 < 12 )
+      $t_h12 += 12;
+  } //end 12-hour time format
+
+  // Add duration
+  $endhour = $t_h12 + $dur_h;
+  $endminute = $minute + $dur_m;
+  $endhour = $endhour + ( $endminute / 60 );
+  $endminute %= 60;
+
+  if ( $TIME_FORMAT == "12" ) {
+    // Convert back to a standard time format
+    if ( $endhour < 12 ) {
+      $endamsel = " checked=\"checked\""; $endpmsel = "";
+    } else {
+      $endamsel = ""; $endpmsel = " checked=\"checked\"";
+    } //end if ( $endhour < 12 )
+    $endhour %= 12;
+    if ( $endhour == 0 ) $endhour = 12;
+  } //end if ( $TIME_FORMAT == "12" )
+} else {
+  $endhour = $h12;
+  $endminute = $minute;
+  $endamsel = $amsel;
+  $endpmsel = $pmsel;
+} //end if ( $id )
+if ( $allday != "Y" && $hour == -1 ) {
+  $endhour = "";
+  $endminute = "";
+} //end if ( $allday != "Y" && $hour == -1 )
+?>
+ <span id="timeentryend" class="tooltip" title="<?php etooltip("end-time-help")?>">&nbsp;-&nbsp;
+  <input type="text" name="endhour" size="2" value="<?php 
+   if ( $allday != "Y" ) echo $endhour;
+  ?>" maxlength="2" />:<input type="text" name="endminute" size="2" value="<?php 
+   if ( $time >= 0 && $allday != "Y" ) printf ( "%02d", $endminute );
+  ?>" maxlength="2" />
+  <?php
+   if ( $TIME_FORMAT == "12" ) {
+    echo "<label><input type=\"radio\" name=\"endampm\" value=\"am\" $endamsel />&nbsp;" .
+     translate("am") . "</label>\n";
+    echo "<label><input type=\"radio\" name=\"endampm\" value=\"pm\" $endpmsel />&nbsp;" .
+     translate("pm") . "</label>\n";
+   }
+  ?>
+ </span>
+</td></tr>
+<?php } ?>
 </table>
 <table>
 <?php
@@ -448,144 +614,15 @@ for ( $i = 0; $i < count ( $site_extras ); $i++ ) {
 // end site-specific extra fields
 ?>
 </table>
+<?php if ( $useTabs ) { ?>
 </div>
+<?php } /* $useTabs */ ?>
 
-<!-- SCHEDULING -->
-<a name="tabsched"></a>
-<div id="tabscontent_sched">
-	<table>
-		<tr><td class="tooltip" title="<?php etooltip("date-help")?>">
-			<?php etranslate("Date")?>:</td><td>
-			<?php
-				print_date_selection ( "", $cal_date )
-			?>
-		</td></tr>
-		<tr><td>&nbsp;</td><td>
-			<select name="timetype" onchange="timetype_handler()">
-				<option value="U" <?php if ( $allday != "Y" && $hour == -1 ) echo " selected=\"selected\""?>><?php etranslate("Untimed event"); ?></option>
-				<option value="T" <?php if ( $allday != "Y" && $hour >= 0 ) echo " selected=\"selected\""?>><?php etranslate("Timed event"); ?></option>
-				<option value="A" <?php if ( $allday == "Y" ) echo " selected=\"selected\""?>><?php etranslate("All day event"); ?></option>
-			</select>
-		</td></tr>
-		<tr id="timeentrystart"><td class="tooltip" title="<?php etooltip("time-help")?>">
-			<?php 
-				echo translate("Time") . ":";
-			?>
-		</td><td>
-<?php
-$h12 = $hour;
-$amsel = " checked=\"checked\""; $pmsel = "";
-if ( $TIME_FORMAT == "12" ) {
-  if ( $h12 < 12 ) {
-    $amsel = " checked=\"checked\""; $pmsel = "";
-  } else {
-    $amsel = ""; $pmsel = " checked=\"checked\"";
-  }
-  $h12 %= 12;
-  if ( $h12 == 0 ) $h12 = 12;
-}
-if ( $time < 0 )
-  $h12 = "";
-?>
-
-	<input type="text" name="hour" size="2" value="<?php if ( $time >= 0 && $allday != 'Y' ) echo $h12;?>" maxlength="2" />:<input type="text" name="minute" size="2" value="<?php if ( $time >= 0 && $allday != "Y" ) printf ( "%02d", $minute );?>" maxlength="2" />
-<?php
-if ( $TIME_FORMAT == "12" ) {
-  echo "<label><input type=\"radio\" name=\"ampm\" value=\"am\" $amsel />&nbsp;" .
-    translate("am") . "</label>\n";
-  echo "<label><input type=\"radio\" name=\"ampm\" value=\"pm\" $pmsel />&nbsp;" .
-    translate("pm") . "</label>\n";
-}
-?>
-
-<?php
-  $dur_h = (int)( $duration / 60 );
-  $dur_m = $duration - ( $dur_h * 60 );
-
-if ($GLOBALS['TIMED_EVT_LEN'] != 'E') { ?>
-	</td></tr>
-	</table>
-	<div id="timeentryduration">
-		<span class="tooltip" title="<?php 
-			etooltip("duration-help")
-		?>"><?php 
-			etranslate("Duration")
-		?>:&nbsp;</span>
-		<input type="text" name="duration_h" id="duration_h" size="2" maxlength="2" value="<?php 
-			if ( $allday != "Y" ) 
-				printf ( "%d", $dur_h );
-		?>" />:<input type="text" name="duration_m" id="duration_m" size="2" maxlength="2" value="<?php 
-			if ( $allday != "Y" ) 
-				printf ( "%02d", $dur_m );
-		?>" />&nbsp;(<label for="duration_h"><?php 
-			echo translate("hours")
-		?></label>: <label for="duration_m"><?php 
-			echo translate("minutes")
-		?></label>)
-	</div>
-<?php } else {
-if ( $id ) {
-  $t_h12 = $h12;
-  if ( $TIME_FORMAT == "12" ) {
-    // Convert to a twenty-four hour time scale
-    if ( !empty ( $amsel ) && $t_h12 == 12 )
-      $t_h12 = 0;
-    if ( !empty ( $pmsel ) && $t_h12 < 12 )
-      $t_h12 += 12;
-  } //end 12-hour time format
-
-  // Add duration
-  $endhour = $t_h12 + $dur_h;
-  $endminute = $minute + $dur_m;
-  $endhour = $endhour + ( $endminute / 60 );
-  $endminute %= 60;
-
-  if ( $TIME_FORMAT == "12" ) {
-    // Convert back to a standard time format
-    if ( $endhour < 12 ) {
-      $endamsel = " checked=\"checked\""; $endpmsel = "";
-    } else {
-      $endamsel = ""; $endpmsel = " checked=\"checked\"";
-    } //end if ( $endhour < 12 )
-    $endhour %= 12;
-    if ( $endhour == 0 ) $endhour = 12;
-  } //end if ( $TIME_FORMAT == "12" )
-} else {
-  $endhour = $h12;
-  $endminute = $minute;
-  $endamsel = $amsel;
-  $endpmsel = $pmsel;
-} //end if ( $id )
-if ( $allday != "Y" && $hour == -1 ) {
-  $endhour = "";
-  $endminute = "";
-} //end if ( $allday != "Y" && $hour == -1 )
-?>
-	<span id="timeentryend" class="tooltip" title="<?php etooltip("end-time-help")?>">&nbsp;-&nbsp;
-		<input type="text" name="endhour" size="2" value="<?php 
-			if ( $allday != "Y" ) 
-				echo $endhour;
-		?>" maxlength="2" />:<input type="text" name="endminute" size="2" value="<?php 
-			if ( $time >= 0 && $allday != "Y" ) 
-				printf ( "%02d", $endminute );
-		?>" maxlength="2" />
-		<?php
-			if ( $TIME_FORMAT == "12" ) {
-				echo "<label><input type=\"radio\" name=\"endampm\" value=\"am\" $endamsel />&nbsp;" .
-					translate("am") . "</label>\n";
-				echo "<label><input type=\"radio\" name=\"endampm\" value=\"pm\" $endpmsel />&nbsp;" .
-					translate("pm") . "</label>\n";
-			}
-		?>
-	</span>
-</td></tr>
-</table>
-<?php } ?>
-</div>
-
+<!-- PARTICIPANTS -->
+<?php if ( $useTabs ) { ?>
 <a name="tabparticipants"></a>
 <div id="tabscontent_participants">
-<!-- PARTICIPANTS -->
+<?php } /* $useTabs */ ?>
 <table>
 <?php
 // Only ask for participants if we are multi-user.
@@ -609,21 +646,21 @@ if ( $single_user == "N" && $show_participants ) {
     $size++;
     $users .= "<option value=\"" . $l . "\"";
     if ( $id > 0 ) {
-      if ( ! empty ( $participants[$l] ) )
+      if ( ! empty ($participants[$l]) )
         $users .= " selected=\"selected\"";
     } else {
-      if ( ! empty ( $defusers ) ) {
+      if ( ! empty ($defusers) ) {
         // default selection of participants was in the URL
         if ( ! empty ( $participants[$l] ) )
           $users .= " selected=\"selected\"";
       } else {
-        if ( ( $l == $login && ! $is_assistant  && ! $is_nonuser_admin ) || ( ! empty ( $user ) && $l == $user ) )
-          $users .= " selected=\"selected\"";
-        else if ( $l == '__public__' &&
-          ! empty ( $public_access_default_selected ) &&
-          $public_access_default_selected == 'Y' )
+        if ( ($l == $login && ! $is_assistant  && ! $is_nonuser_admin) || (! empty ($user) && $l == $user) )
           $users .= " selected=\"selected\"";
       }
+      if ( $l == '__public__' &&
+        ! empty ($public_access_default_selected) &&
+         $public_access_default_selected == 'Y' )
+           $users .= " selected=\"selected\"";
     }
     $users .= ">" . $userlist[$i]['cal_fullname'] . "</option>\n";
   }
@@ -633,14 +670,16 @@ if ( $single_user == "N" && $show_participants ) {
   else if ( $size > 5 )
     $size = 5;
   print "<tr title=\"" . 
-	tooltip("participants-help") . "\"><td class=\"tooltipselect\">\n<label for=\"entry_part\">" . 
-	translate("Participants") . ":</label></td><td>\n";
+ tooltip("participants-help") . "\"><td class=\"tooltipselect\">\n<label for=\"entry_part\">" . 
+ translate("Participants") . ":</label></td><td>\n";
   print "<select name=\"participants[]\" id=\"entry_part\" size=\"$size\" multiple=\"multiple\">$users\n";
   print "</select>\n";
   if ( $groups_enabled == "Y" ) {
     echo "<input type=\"button\" onclick=\"selectUsers()\" value=\"" .
       translate("Select") . "...\" />\n";
   }
+  echo "<input type=\"button\" onclick=\"showSchedule()\" value=\"" .
+    translate("Availability") . "...\" />\n";
   print "</td></tr>\n";
 
   // external users
@@ -654,116 +693,122 @@ if ( $single_user == "N" && $show_participants ) {
 }
 ?>
 </table>
+<?php if ( $useTabs ) { ?>
 </div>
+<?php } /* $useTabs */ ?>
 
 <!-- REPEATING INFO -->
+<?php if ( $disable_repeating_field != "Y" ) { ?>
+<?php if ( $useTabs ) { ?>
 <a name="tabpete"></a>
 <div id="tabscontent_pete">
+<?php } /* $useTabs */ ?>
 <table>
-<?php if ( $disable_repeating_field != "Y" ) { ?>
 <tr style="vertical-align:top;"><td class="tooltip" title="<?php etooltip("repeat-type-help")?>">
-	<?php etranslate("Repeat Type")?>:</td><td>
-	<select name="rpt_type" id="rpttype" onchange="rpttype_handler()">
-	<?php
-		echo "<option value=\"none\"" . 
-			( strcmp ( $rpt_type, 'none' ) == 0 ? " selected=\"selected\"" : "" ) . " />" . 
-			translate("None") . 
-		"</option>\n";
-		echo "<option value=\"daily\"" . 
-			( strcmp ( $rpt_type, 'daily' ) == 0 ? " selected=\"selected\"" : "" ) . " />" . 
-			translate("Daily") . 
-		"</option>\n";
-		echo "<option value=\"weekly\"" . 
-			( strcmp ( $rpt_type, 'weekly' ) == 0 ? " selected=\"selected\"" : "" ) . " />" . 
-			translate("Weekly") . 
-		"</option>\n";
-		echo "<option value=\"monthlyByDay\"" . 
-			( strcmp ( $rpt_type, 'monthlyByDay' ) == 0 ? " selected=\"selected\"" : "" ) . " />" . 
-			translate("Monthly") . " (" . translate("by day") . ")" . "
-		</option>\n";
-		echo "<option value=\"monthlyByDayR\"" . 
-			( strcmp ( $rpt_type, 'monthlyByDayR' ) == 0 ? " selected=\"selected\"" : "" ) . " />" . 
-			translate("Monthly") . " (" . translate("by day (from end)") . ")" . 
-		"</option>\n";
-		echo "<option value=\"monthlyByDate\"" . 
-			( strcmp ( $rpt_type, 'monthlyByDate' ) == 0 ? " selected=\"selected\"" : "" ) . " />" . 
-			translate("Monthly") . " (" . translate("by date") . ")" . 
-		"</option>\n";
-		echo "<option value=\"yearly\"" . 
-			( strcmp ( $rpt_type, 'yearly' ) == 0 ? " selected=\"selected\"" : "" ) . " />" . 
-			translate("Yearly") . 
-		"</option>\n";
-	?>
-	</select>
+ <label for="rpttype"><?php etranslate("Repeat Type")?>:</label></td><td>
+ <select name="rpt_type" id="rpttype" onchange="rpttype_handler()">
+<?php
+ echo "  <option value=\"none\"" . 
+  ( strcmp ( $rpt_type, 'none' ) == 0 ? " selected=\"selected\"" : "" ) . ">" . 
+  translate("None") . 
+ "</option>\n";
+ echo "  <option value=\"daily\"" . 
+  ( strcmp ( $rpt_type, 'daily' ) == 0 ? " selected=\"selected\"" : "" ) . ">" . 
+  translate("Daily") . 
+ "</option>\n";
+ echo "  <option value=\"weekly\"" . 
+  ( strcmp ( $rpt_type, 'weekly' ) == 0 ? " selected=\"selected\"" : "" ) . ">" . 
+  translate("Weekly") . 
+ "</option>\n";
+ echo "  <option value=\"monthlyByDay\"" . 
+  ( strcmp ( $rpt_type, 'monthlyByDay' ) == 0 ? " selected=\"selected\"" : "" ) . ">" . 
+  translate("Monthly") . " (" . translate("by day") . ")" . "
+ </option>\n";
+ echo "  <option value=\"monthlyByDayR\"" . 
+  ( strcmp ( $rpt_type, 'monthlyByDayR' ) == 0 ? " selected=\"selected\"" : "" ) . ">" . 
+  translate("Monthly") . " (" . translate("by day (from end)") . ")" . 
+ "</option>\n";
+ echo "  <option value=\"monthlyByDate\"" . 
+  ( strcmp ( $rpt_type, 'monthlyByDate' ) == 0 ? " selected=\"selected\"" : "" ) . ">" . 
+  translate("Monthly") . " (" . translate("by date") . ")" . 
+ "</option>\n";
+ echo "  <option value=\"yearly\"" . 
+  ( strcmp ( $rpt_type, 'yearly' ) == 0 ? " selected=\"selected\"" : "" ) . ">" . 
+  translate("Yearly") . 
+ "</option>\n";
+?>
+ </select>
 </td></tr>
-<tr id="enddate" style="visibility:hidden;"><td class="tooltip" title="<?php etooltip("repeat-end-date-help")?>">
-	<?php etranslate("Repeat End Date")?>:</td><td>
-	<label><input type="checkbox" name="rpt_end_use" value="y" <?php 
-		echo ( ! empty ( $rpt_end ) ? " checked=\"checked\"" : "" ); 
-	?> />&nbsp;<?php etranslate("Use end date")?></label>
-	&nbsp;&nbsp;&nbsp;
-	<span class="end_day_selection"><?php
-		print_date_selection ( "rpt_", $rpt_end_date ? $rpt_end_date : $cal_date )
-	?></span>
+<tr id="rptenddate" style="visibility:hidden;"><td class="tooltip" title="<?php etooltip("repeat-end-date-help")?>">
+ <?php etranslate("Repeat End Date")?>:</td><td>
+ <label><input type="checkbox" name="rpt_end_use" value="y" <?php 
+  echo ( ! empty ( $rpt_end ) ? " checked=\"checked\"" : "" ); 
+ ?> />&nbsp;<?php etranslate("Use end date")?></label>
+ &nbsp;&nbsp;&nbsp;
+ <span class="end_day_selection"><?php
+  print_date_selection ( "rpt_", $rpt_end_date ? $rpt_end_date : $cal_date )
+ ?></span>
 </td></tr>
-<tr id="freq" style="visibility:hidden;" title="<?php etooltip("repeat-frequency-help")?>"><td class="tooltip">
-	<label for="entry_freq"><?php etranslate("Frequency")?>:</label></td><td>
-	<input type="text" name="rpt_freq" id="entry_freq" size="4" maxlength="4" value="<?php echo $rpt_freq; ?>" />
+<tr id="rptfreq" style="visibility:hidden;" title="<?php etooltip("repeat-frequency-help")?>"><td class="tooltip">
+ <label for="entry_freq"><?php etranslate("Frequency")?>:</label></td><td>
+ <input type="text" name="rpt_freq" id="entry_freq" size="4" maxlength="4" value="<?php echo $rpt_freq; ?>" />
 </td></tr>
-<tr id="day" style="visibility:hidden;" title="<?php etooltip("repeat-day-help")?>"><td class="tooltip">
-	<?php etranslate("Repeat Day")?>:&nbsp;</td><td>
-	<?php
-		if( $WEEK_START != 1)
-			echo "<label><input type=\"checkbox\" name=\"rpt_sun\" value=\"y\"" 
-				. (!empty($rpt_sun)?" checked=\"checked\"":"") . " />&nbsp;" . translate("Sunday") . 
-			"</label>\n";
-			echo "<label><input type=\"checkbox\" name=\"rpt_mon\" value=\"y\"" 
-				. (!empty($rpt_mon)?" checked=\"checked\"":"") . " />&nbsp;" . translate("Monday") . 
-			"</label>\n";
-			echo "<label><input type=\"checkbox\" name=\"rpt_tue\" value=\"y\"" 
-				. (!empty($rpt_tue)?" checked=\"checked\"":"") . " />&nbsp;" . translate("Tuesday") . 
-			"</label>\n";
-			echo "<label><input type=\"checkbox\" name=\"rpt_wed\" value=\"y\"" 
-				. (!empty($rpt_wed)?" checked=\"checked\"":"") . " />&nbsp;" . translate("Wednesday") . 
-			"</label>\n";
-			echo "<label><input type=\"checkbox\" name=\"rpt_thu\" value=\"y\"" 
-				. (!empty($rpt_thu)?" checked=\"checked\"":"") . " />&nbsp;" . translate("Thursday") . 
-			"</label>\n";
-			echo "<label><input type=\"checkbox\" name=\"rpt_fri\" value=\"y\"" 
-				. (!empty($rpt_fri)?" checked=\"checked\"":"") . " />&nbsp;" . translate("Friday") . 
-			"</label>\n";
-			echo "<label><input type=\"checkbox\" name=\"rpt_sat\" value=\"y\"" 
-				. (!empty($rpt_sat)?" checked=\"checked\"":"") . " />&nbsp;" . translate("Saturday") . 
-			"</label>\n";
-			if( $WEEK_START == 1)
-				echo "<label><input type=\"checkbox\" name=\"rpt_sun\" value=\"y\"" 
-					. (!empty($rpt_sun)?" checked=\"checked\"":"") . " />&nbsp;" . translate("Sunday") . 
-				"</label>\n";
-	?></td></tr>
+<tr id="rptday" style="visibility:hidden;" title="<?php etooltip("repeat-day-help")?>"><td class="tooltip">
+ <?php etranslate("Repeat Day")?>:&nbsp;</td><td>
+ <?php
+  if( $WEEK_START != 1)
+   echo "<label><input type=\"checkbox\" name=\"rpt_sun\" value=\"y\"" 
+    . (!empty($rpt_sun)?" checked=\"checked\"":"") . " />&nbsp;" . translate("Sunday") . 
+   "</label>\n";
+  echo "<label><input type=\"checkbox\" name=\"rpt_mon\" value=\"y\"" 
+   . (!empty($rpt_mon)?" checked=\"checked\"":"") . " />&nbsp;" . translate("Monday") . 
+  "</label>\n";
+  echo "<label><input type=\"checkbox\" name=\"rpt_tue\" value=\"y\"" 
+   . (!empty($rpt_tue)?" checked=\"checked\"":"") . " />&nbsp;" . translate("Tuesday") . 
+  "</label>\n";
+  echo "<label><input type=\"checkbox\" name=\"rpt_wed\" value=\"y\"" 
+   . (!empty($rpt_wed)?" checked=\"checked\"":"") . " />&nbsp;" . translate("Wednesday") . 
+  "</label>\n";
+  echo "<label><input type=\"checkbox\" name=\"rpt_thu\" value=\"y\"" 
+   . (!empty($rpt_thu)?" checked=\"checked\"":"") . " />&nbsp;" . translate("Thursday") . 
+  "</label>\n";
+  echo "<label><input type=\"checkbox\" name=\"rpt_fri\" value=\"y\"" 
+   . (!empty($rpt_fri)?" checked=\"checked\"":"") . " />&nbsp;" . translate("Friday") . 
+  "</label>\n";
+  echo "<label><input type=\"checkbox\" name=\"rpt_sat\" value=\"y\"" 
+   . (!empty($rpt_sat)?" checked=\"checked\"":"") . " />&nbsp;" . translate("Saturday") . 
+  "</label>\n";
+  if( $WEEK_START == 1)
+   echo "<label><input type=\"checkbox\" name=\"rpt_sun\" value=\"y\"" 
+    . (!empty($rpt_sun)?" checked=\"checked\"":"") . " />&nbsp;" . translate("Sunday") . 
+   "</label>\n";
+ ?></td></tr>
 </table>
-</div>
-</div>
-<?php } ?>
 
-<table style="border-width:0px;">
+<?php if ( $useTabs ) { ?>
+</div> <!-- End tabscontent_pete -->
+<?php } /* $useTabs */ ?>
+<?php } ?>
+</div> <!-- End tabscontent -->
+<table  style="border-width:0px;">
 <tr><td>
-	<script type="text/javascript">
+ <script type="text/javascript">
 <!-- <![CDATA[
   document.writeln ( '<input type="button" value="<?php etranslate("Save")?>" onclick="validate_and_submit()" />' );
 //]]> -->
-	</script>
-	<noscript>
-		<input type="submit" value="<?php etranslate("Save")?>" />
-	</noscript>
+ </script>
+ <noscript>
+  <input type="submit" value="<?php etranslate("Save")?>" />
+ </noscript>
 </td></tr>
 </table>
 <input type="hidden" name="participant_list" value="" />
 </form>
 
 <?php if ( $id > 0 && ( $login == $create_by || $single_user == "Y" || $is_admin ) ) { ?>
-	<a href="del_entry.php?id=<?php echo $id;?>" onclick="return confirm('<?php etranslate("Are you sure you want to delete this entry?")?>');"><?php etranslate("Delete entry")?></a><br />
+ <a href="del_entry.php?id=<?php echo $id;?>" onclick="return confirm('<?php etranslate("Are you sure you want to delete this entry?")?>');"><?php etranslate("Delete entry")?></a><br />
 <?php 
-	} //end if clause for delete link
+ } //end if clause for delete link
 } else { 
   echo translate("You are not authorized to edit this entry") . ".";
 } //end if ( $can_edit )
