@@ -13,7 +13,16 @@ if ( ! empty ( $override ) && ! empty ( $override_date ) ) {
   $do_override = true;
   $old_id = $id;
 }
+// Remember previous cal_goup_id if present
+$old_id = ( ! empty ( $parent ) ? $parent : $old_id );
 
+if ( empty ( $TZ_OFFSET ) ) {
+  $TZ_OFFSET = 0;
+}
+
+if ( empty ( $endhour ) ) {
+  $endhour = 0;
+}
 // Modify the time to be server time rather than user time.
 if ( ! empty ( $hour ) && ( $timetype == 'T' ) ) {
   // Convert to 24 hour before subtracting TZ_OFFSET so am/pm isn't confused.
@@ -21,17 +30,18 @@ if ( ! empty ( $hour ) && ( $timetype == 'T' ) ) {
   // so the code can be deleted
   if ( $TIME_FORMAT == '12' && $hour < 12 ) {
     if ( $ampm == 'pm' )
-    	$hour += 12;
+     $hour += 12;
   } elseif ($TIME_FORMAT == '12' && $hour == '12' && $ampm == 'am' ) {
     $hour = 0;
   }
   if ( $GLOBALS['TIMED_EVT_LEN'] == 'E') {
-    if ( !empty ( $endhour ) ) {
+    if ( isset ( $endhour ) && $TIME_FORMAT == '12' ) {
       // Convert end time to a twenty-four hour time scale.
-      if ( $endampm == 'pm' && $endhour < 12 )
+      if ( $endampm == 'pm' && $endhour < 12 ) {
         $endhour += 12;
-      elseif ( $endampm == 'am' && $endhour == 12 )
+      } elseif ( $endampm == 'am' && $endhour == 12 ) {
         $endhour = 0;
+      }
     }
   }
   $TIME_FORMAT=24;
@@ -54,23 +64,15 @@ if ( ! empty ( $hour ) && ( $timetype == 'T' ) ) {
     $day = date ( "d", $date );
     $year = date ( "Y", $date );
   }
-}
 
-// Return the time in HHMMSS format of input time + duration
-// $time - format "235900"
-// $duration - number of minutes
-function add_duration ( $time, $duration ) {
-  $hour = (int) ( $time / 10000 );
-  $min = ( $time / 100 ) % 100;
-  $minutes = $hour * 60 + $min + $duration;
-  $h = $minutes / 60;
-  $m = $minutes % 60;
-  $ret = sprintf ( "%d%02d00", $h, $m );
-  //echo "add_duration ( $time, $duration ) = $ret <br />\n";
-  return $ret;
+  // Must adjust $endhour too
+  if ($TZ_OFFSET) {
+    $endhour -= $TZ_OFFSET;
+    if ( $endhour < 0 )   $endhour += 24;
+    if ( $endhour >= 24 ) $endhour -= 24;
+  }
 }
 
-
 // Make sure this user is really allowed to edit this event.
 // Otherwise, someone could hand type in the URL to edit someone else's
 // event.
@@ -80,23 +82,28 @@ function add_duration ( $time, $duration ) {
 //   - user created event
 //   - user is participant
 $can_edit = false;
+// value may be needed later for recreating event
+$old_create_by = ( ! empty ( $user )? $user : '');
 if ( empty ( $id ) ) {
   // New event...
   $can_edit = true;
-} else if ( $is_admin ) {
-  $can_edit = true;
 } else {
   // event owner or assistant event ?
   $sql = "SELECT cal_create_by FROM webcal_entry WHERE cal_id = '$id'";
   $res = dbi_query($sql);
   if ($res) {
     $row = dbi_fetch_row ( $res );
+    // value may be needed later for recreating event
+    $old_create_by = $row[0];
     if (( $row[0] == $login ) || (( $user == $row[0] ) && ( $is_assistant || $is_nonuser_admin )))
       $can_edit = true;
     dbi_free_result ( $res );
   } else
     $error = translate("Database error") . ": " . dbi_error ();
 }
+if ( $is_admin ) {
+  $can_edit = true;
+}
 if ( empty ( $error ) && ! $can_edit ) {
   // is user a participant of that event ?
   $sql = "SELECT cal_id FROM webcal_entry_user WHERE cal_id = '$id' " .
@@ -111,8 +118,9 @@ if ( empty ( $error ) && ! $can_edit ) {
     $error = translate("Database error") . ": " . dbi_error ();
 }
 
-if ( ! $can_edit && empty ( $error ) )
+if ( ! $can_edit && empty ( $error ) ) {
   $error = translate ( "You are not authorized" );
+}
 
 // If display of participants is disabled, set the participant list
 // to the event creator.  This also works for single-user mode.
@@ -120,9 +128,15 @@ if ( ! $can_edit && empty ( $error ) )
 // was no selection list available in the form or because the user
 // refused to select any participant from the list), then we will
 // assume the only participant is the current user.
-if ( ! strlen ( $participants[0] ) )
+if ( empty ( $participants[0] ) ) {
   $participants[0] = $login;
-
+  // There might be a better way to do this, but if Admin sets this value,
+  // WebCalendar should respect it
+  if ( ! empty ( $public_access_default_selected ) &&
+    $public_access_default_selected == "Y" ) {
+    $participants[1] = "__public__";     
+  }
+}
 // If "all day event" was selected, then we set the event time
 // to be 12AM with a duration of 24 hours.
 // We don't actually store the "all day event" flag per se.  This method
@@ -132,6 +146,10 @@ if ( ! strlen ( $participants[0] ) )
 // Note that if someone actually wants to create an event that starts
 // at midnight and lasts exactly 24 hours, it will be treated in the
 // same manner.
+
+$duration_h = getValue ( "duration_h" );
+$duration_m = getValue ( "duration_m" );
+
 if ( $timetype == "A" ) {
   $duration_h = 24;
   $duration_m = 0;
@@ -149,23 +167,25 @@ if ( $hour > 0 && $timetype != 'U' ) {
       $ampmt = 'pm';
     }
     $hour %= 12;
-    if ( $ampmt == 'pm' )
+    if ( $ampmt == 'pm' ) {
       $hour += 12;
+    }
   }
 }
 //echo "SERVER HOUR: $hour $ampm";
 
 if ( $GLOBALS['TIMED_EVT_LEN'] == 'E' && $timetype == "T" ) {
-    if ( empty ( $endhour ) )
+    if ( ! isset ( $endhour ) ) {
         $duration = 0;
-    else {
+    } else {
       // Calculate duration.
       $endmins = ( 60 * $endhour ) + $endminute;
       $startmins = ( 60 * $hour ) + $minute;
       $duration = $endmins - $startmins;
     }
-    if ( $duration < 0 )
+    if ( $duration < 0 ) {
         $duration = 0;
+    }
 }
 
 // handle external participants
@@ -174,15 +194,19 @@ $ext_emails = array ();
 $matches = array ();
 $ext_count = 0;
 if ( $single_user == "N" &&
-  ! empty ( $allow_external_users ) && $allow_external_users == "Y" ) {
+  ! empty ( $allow_external_users ) && 
+  $allow_external_users == "Y" &&
+  ! empty ( $externalparticipants ) ) {
   $lines = explode ( "\n", $externalparticipants );
-  if ( ! is_array ( $lines ) )
+  if ( ! is_array ( $lines ) ) {
     $lines = array ( $externalparticipants );
+  }
   if ( is_array ( $lines ) ) {
     for ( $i = 0; $i < count ( $lines ); $i++ ) {
       $ext_words = explode ( " ", $lines[$i] );
-      if ( ! is_array ( $ext_words ) )
+      if ( ! is_array ( $ext_words ) ) {
         $ext_words = array ( $lines[$i] );
+      }
       if ( is_array ( $ext_words ) ) {
         $ext_names[$ext_count] = "";
         $ext_emails[$ext_count] = "";
@@ -195,11 +219,20 @@ if ( $single_user == "N" &&
             $ext_emails[$ext_count] = preg_replace ( "/[<>]/", "",
               $ext_emails[$ext_count] );
           } else {
-            if ( strlen ( $ext_names[$ext_count] ) )
+            if ( strlen ( $ext_names[$ext_count] ) ) {
               $ext_names[$ext_count] .= " ";
+            }
             $ext_names[$ext_count] .= $ext_words[$j];
           }
         }
+        // Test for duplicate Names
+        if ( $i > 0 ) {
+          for ( $k = $i ; $k > 0 ; $k-- ) {
+            if ( $ext_names[$i] == $ext_names[$k] ) { 
+              $ext_names[$i]  .= "[$k]";     
+            }
+          }
+        }
         if ( strlen ( $ext_emails[$ext_count] ) &&
           empty ( $ext_names[$ext_count] ) ) {
           $ext_names[$ext_count] = $ext_emails[$ext_count];
@@ -218,21 +251,23 @@ if ( $allow_conflicts != "Y" && empty ( $confirm_conflicts ) &&
   strlen ( $hour ) > 0 && $timetype != 'U' ) {
   $date = mktime ( 3, 0, 0, $month, $day, $year );
   $str_cal_date = date ( "Ymd", $date );
-  if ( strlen ( $hour ) > 0 )
+  if ( strlen ( $hour ) > 0 ) {
     $str_cal_time = sprintf ( "%02d%02d00", $hour, $minute );
-  if ( ! empty ( $rpt_end_use ) )
+  }
+  if ( ! empty ( $rpt_end_use ) ) {
     $endt = mktime ( 3, 0, 0, $rpt_month, $rpt_day,$rpt_year );
-  else
+  } else {
     $endt = 'NULL';
+  }
 
   if ($rpt_type == 'weekly') {
-    $dayst = ( $rpt_sun ? 'y' : 'n' )
-      . ( $rpt_mon ? 'y' : 'n' )
-      . ( $rpt_tue ? 'y' : 'n' )
-      . ( $rpt_wed ? 'y' : 'n' )
-      . ( $rpt_thu ? 'y' : 'n' )
-      . ( $rpt_fri ? 'y' : 'n' )
-      . ( $rpt_sat ? 'y' : 'n' );
+    $dayst = ( empty( $rpt_sun )  ? 'n' : 'y' )
+      . (  empty( $rpt_mon )  ? 'n' : 'y' )
+      . (  empty( $rpt_tue )  ? 'n' : 'y' )
+      . (  empty( $rpt_wed )  ? 'n' : 'y' )
+      . (  empty( $rpt_thu )  ? 'n' : 'y' )
+      . (  empty( $rpt_fri )  ? 'n' : 'y' )
+      . (  empty( $rpt_sat )  ? 'n' : 'y' );
   } else {
     $dayst = "nnnnnnn";
   }
@@ -248,24 +283,23 @@ if ( $allow_conflicts != "Y" && empty ( $confirm_conflicts ) &&
         $ex_days[] = $row[0];
       }
       dbi_free_result ( $res );
-    } else
+    } else {
       $error = translate("Database error") . ": " . dbi_error ();
+    }
   }
-  
+
   $dates = get_all_dates ( $date, $rpt_type, $endt, $dayst,
     $ex_days, $rpt_freq );
-
-  //echo $id . "<br />";
+    
   $conflicts = check_for_conflicts ( $dates, $duration, $hour, $minute,
     $participants, $login, empty ( $id ) ? 0 : $id );
-
 }
 if ( empty ( $error ) && ! empty ( $conflicts ) ) {
   $error = translate("The following conflicts with the suggested time") .
     ": <ul>$conflicts</ul>";
 }
-
-
+//Avoid Undefined variable message
+$msg = '';
 if ( empty ( $error ) ) {
   $newevent = true;
   // now add the entries
@@ -290,8 +324,9 @@ if ( empty ( $error ) ) {
         $old_category[$tmprow[0]] = $tmprow[2];
       }
       dbi_free_result ( $res );
-    } else
+    } else {
       $error = translate("Database error") . ": " . dbi_error ();
+    }
     if ( empty ( $error ) ) {
       dbi_query ( "DELETE FROM webcal_entry WHERE cal_id = $id" );
       dbi_query ( "DELETE FROM webcal_entry_user WHERE cal_id = $id" );
@@ -309,7 +344,6 @@ if ( empty ( $error ) ) {
       $error = translate("Database error") . ": " . dbi_error ();
     }
   }
-
   $sql = "INSERT INTO webcal_entry ( cal_id, " .
     ( $old_id > 0 ? " cal_group_id, " : "" ) .
     "cal_create_by, cal_date, " .
@@ -317,33 +351,40 @@ if ( empty ( $error ) ) {
     "cal_access, cal_type, cal_name, cal_description ) " .
     "VALUES ( $id, " .
     ( $old_id > 0 ? " $old_id, " : "" ) .
-    "'" . ($is_assistant || $is_nonuser_admin ? $user : $login) . "', ";
-
+    "'" . ( ! empty ( $old_create_by ) && 
+      ( ( $is_admin && ! $newevent ) || $is_assistant || 
+      $is_nonuser_admin ) ? $old_create_by : $login ) . "', ";
+    
   $date = mktime ( 3, 0, 0, $month, $day, $year );
   $sql .= date ( "Ymd", $date ) . ", ";
   if ( strlen ( $hour ) > 0 && $timetype != 'U' ) {
     $sql .= sprintf ( "%02d%02d00, ", $hour, $minute );
-  } else
+  } else {
     $sql .= "-1, ";
+  }
   $sql .= date ( "Ymd" ) . ", " . date ( "Gis" ) . ", ";
   $sql .= sprintf ( "%d, ", $duration );
   $sql .= sprintf ( "%d, ", $priority );
-  $sql .= "'$access', ";
-  if ( $rpt_type != 'none' )
+  $sql .= empty ( $access ) ? "'P', " : "'$access', ";
+  if (  ! empty ( $rpt_type ) && $rpt_type != 'none' ) {
     $sql .= "'M', ";
-  else
+  } else {
     $sql .= "'E', ";
+  }
 
-  if ( strlen ( $name ) == 0 )
+  if ( strlen ( $name ) == 0 ) {
     $name = translate("Unnamed Event");
+  }
   $sql .= "'" . $name .  "', ";
-  if ( strlen ( $description ) == 0 )
+  if ( strlen ( $description ) == 0 ) {
     $description = $name;
+  }
   $sql .= "'" . $description . "' )";
   
   if ( empty ( $error ) ) {
-    if ( ! dbi_query ( $sql ) )
+    if ( ! dbi_query ( $sql ) ) {
       $error = translate("Database error") . ": " . dbi_error ();
+    }
   }
 
   // log add/update
@@ -369,36 +410,68 @@ if ( empty ( $error ) ) {
       // and we are the admin
       if ( !$found_flag && !$is_nonuser_admin) {
         // only send mail if their email address is filled in
-        $do_send = get_pref_setting ( $old_participants, "EMAIL_EVENT_DELETED" );
+        $do_send = get_pref_setting ( $old_participant, "EMAIL_EVENT_DELETED" );
+        $user_TZ = get_pref_setting ( $old_participant, "TZ_OFFSET" );
+        $user_language = get_pref_setting ( $old_participant, "LANGUAGE" );
         user_load_variables ( $old_participant, "temp" );
         if ( $old_participant != $login && strlen ( $tempemail ) &&
           $do_send == "Y" && $send_email != "N" ) {
-          $fmtdate = sprintf ( "%04d%02d%02d", $year, $month, $day );
+
+          // Want date/time in user's timezone
+          $user_hour = $hour + $user_TZ;
+          if ( $user_hour < 0 ) {
+            $user_hour += 24;
+            // adjust date
+            $user_date = mktime ( 3, 0, 0, $month, $day, $year );
+            $user_date -= $ONE_DAY;
+            $user_month = date ( "m", $date );
+            $user_day = date ( "d", $date );
+            $user_year = date ( "Y", $date );
+          } elseif ( $user_hour >= 24 ) {
+            $user_hour -= 24;
+            // adjust date
+            $user_date = mktime ( 3, 0, 0, $month, $day, $year );
+            $user_date += $ONE_DAY;
+            $user_month = date ( "m", $date );
+            $user_day = date ( "d", $date );
+            $user_year = date ( "Y", $date );
+          } else {
+            $user_month = $month;
+            $user_day = $day;
+            $user_year = $year;
+          }
+          if (($GLOBALS['LANGUAGE'] != $user_language) && 
+            ! empty ( $user_language ) && ( $user_language != 'none' )){
+            reset_language ( $user_language );
+          }
+          //do_debug($user_language);    
+          $fmtdate = sprintf ( "%04d%02d%02d", $user_year, $user_month, $user_day );
           $msg = translate("Hello") . ", " . $tempfullname . ".\n\n" .
             translate("An appointment has been canceled for you by") .
             " " . $login_fullname .  ". " .
             translate("The subject was") . " \"" . $name . "\"\n\n" .
             translate("The description is") . " \"" . $description . "\"\n" .
             translate("Date") . ": " . date_to_str ( $fmtdate ) . "\n" .
-            ( ( empty ( $hour ) && empty ( $minute ) ) ? "" :
+            ( ( empty ( $user_hour ) && empty ( $minute ) ) ? "" :
             translate("Time") . ": " .
-              display_time ( ( $hour * 10000 ) + ( $minute * 100 ) ) ) .
+              display_time ( ( $user_hour * 10000 ) + ( $minute * 100 ), true ) ) .
             "\n\n\n";
           // add URL to event, if we can figure it out
           if ( ! empty ( $server_url ) ) {
             $url = $server_url .  "view_entry.php?id=" .  $id;
             $msg .= $url . "\n\n";
           }
-	  # translate("Title")
-          if ( strlen ( $login_email ) )
+         
+          if ( strlen ( $login_email ) ) {
             $extra_hdrs = "From: $login_email\r\nX-Mailer: " . translate($application_name);
-          else
+          } else {
             $extra_hdrs = "From: $email_fallback_from\r\nX-Mailer: " . translate($application_name);
+          }
           mail ( $tempemail,
             translate($application_name) . " " . translate("Notification") . ": " . $name,
             html_to_8bits ($msg), $extra_hdrs );
           activity_log ( $id, $login, $old_participant, $LOG_NOTIFICATION,
-	    "User removed from participants list" );
+     "User removed from participants list" );
         }
       }
     }
@@ -423,36 +496,53 @@ if ( empty ( $error ) ) {
       $my_cat_id = $cat_id;
     } else if ( ! $newevent ) {
       // keep the old status if no email will be sent
-      $send_user_mail = ( $old_status[$participants[$i]] == '' ||
-        $entry_changed ) ?  true : false;
-      $tmp_status = ( $old_status[$participants[$i]] && ! $send_user_mail ) ?
-        $old_status[$participants[$i]] : "W";
+        $send_user_mail = ( empty ( $old_status[$participants[$i]] ) ||
+          $entry_changed ) ?  true : false;
+        $tmp_status = ( ! empty ( $old_status[$participants[$i]] ) && ! $send_user_mail ) ?
+          $old_status[$participants[$i]] : "W";
       $status = ( $participants[$i] != $login && boss_must_approve_event ( $login, $participants[$i] ) && $require_approvals == "Y" && ! $is_nonuser_admin ) ?
         $tmp_status : "A";
       $tmp_cat = ( ! empty ( $old_category[$participants[$i]]) ) ?
         $old_category[$participants[$i]] : 'NULL';
+      $tmp_cat = ( $participants[$i] == $user ) ? $cat_id : $tmp_cat;
       // Allow cat to be changed for public access (if admin user)
-      if ( $participants[$i] == "__public__" && $is_admin )
+      if ( $participants[$i] == "__public__" && $is_admin ) {
         $tmp_cat = $cat_id;
+      }
+
       // If user is admin and this event was previously approved for public,
       // keep it as approved even though date/time may have changed
       // This goes against stricter security, but it confuses users to have
       // to re-approve events they already approved.
       if ( $participants[$i] == "__public__" && $is_admin &&
-        $old_status['__public__'] == 'A' )
+        $old_status['__public__'] == 'A' ) {
         $status = 'A';
+      }
       $my_cat_id = ( $participants[$i] != $login ) ? $tmp_cat : $cat_id;
-    } else {
+      // If user is admin and
+      // if it's a global cat, then set it for other users as well.
+      if ( $is_admin && ! empty ( $categories[$cat_id] ) &&
+        empty ( $category_owners[$cat_id] ) ) {
+        // found categ. and owner set to NULL; it is global
+        $my_cat_id = $cat_id;
+      }
+    } else {  // New Event
       $send_user_mail = true;
-      $status = ( $participants[$i] != $login && boss_must_approve_event ( $login, $participants[$i] ) && $require_approvals == "Y" && ! $is_nonuser_admin ) ?
+      $status = ( $participants[$i] != $login && 
+        boss_must_approve_event ( $login, $participants[$i] ) && 
+        $require_approvals == "Y" && ! $is_nonuser_admin ) ?
         "W" : "A";
+      // If admin, no need to approve Public Access Events
+      if ( $participants[$i] == "__public__" && $is_admin ) {
+        $status = "A";
+      }
       if ( $participants[$i] == $login ) {
         $my_cat_id = $cat_id;
       } else {
         // if it's a global cat, then set it for other users as well.
         if ( ! empty ( $categories[$cat_id] ) &&
           empty ( $category_owners[$cat_id] ) ) {
-          // found categ. and owner set to NULL; it is global
+          // found cat. and owner set to NULL; it is global
           $my_cat_id = $cat_id;
         } else {
           // not global category
@@ -482,22 +572,56 @@ if ( empty ( $error ) ) {
         // only send mail if their email address is filled in
         $do_send = get_pref_setting ( $participants[$i],
            $newevent ? "EMAIL_EVENT_ADDED" : "EMAIL_EVENT_UPDATED" );
+        $user_TZ = get_pref_setting ( $participants[$i], "TZ_OFFSET" );
+        $user_language = get_pref_setting ( $participants[$i], "LANGUAGE" );
         user_load_variables ( $participants[$i], "temp" );
-        if ( $participants[$i] != $login && boss_must_be_notified ( $login, $participants[$i] ) && strlen ( $tempemail ) &&
+        if ( $participants[$i] != $login && 
+          boss_must_be_notified ( $login, $participants[$i] ) && 
+          strlen ( $tempemail ) &&
           $do_send == "Y" && $send_user_mail && $send_email != "N" ) {
-          $fmtdate = sprintf ( "%04d%02d%02d", $year, $month, $day );
+
+          // Want date/time in user's timezone
+          $user_hour = $hour + $user_TZ;
+          if ( $user_hour < 0 ) {
+            $user_hour += 24;
+            // adjust date
+            $user_date = mktime ( 3, 0, 0, $month, $day, $year );
+            $user_date -= $ONE_DAY;
+            $user_month = date ( "m", $date );
+            $user_day = date ( "d", $date );
+            $user_year = date ( "Y", $date );
+          } elseif ( $user_hour >= 24 ) {
+            $user_hour -= 24;
+            // adjust date
+            $user_date = mktime ( 3, 0, 0, $month, $day, $year );
+            $user_date += $ONE_DAY;
+            $user_month = date ( "m", $date );
+            $user_day = date ( "d", $date );
+            $user_year = date ( "Y", $date );
+          } else {
+            $user_month = $month;
+            $user_day = $day;
+            $user_year = $year;
+          }
+          if (($GLOBALS['LANGUAGE'] != $user_language) && 
+            ! empty ( $user_language ) && ( $user_language != 'none' )) {
+             reset_language ( $user_language );
+          }
+          //do_debug($user_language);
+          $fmtdate = sprintf ( "%04d%02d%02d", $user_year, $user_month, $user_day );
           $msg = translate("Hello") . ", " . $tempfullname . ".\n\n";
-          if ( $newevent || $old_status[$participants[$i]] == '' )
+          if ( $newevent || ( empty ( $old_status[$participants[$i]] ) ) ) {
             $msg .= translate("A new appointment has been made for you by");
-          else
+          } else {
             $msg .= translate("An appointment has been updated by");
+          }
           $msg .= " " . $login_fullname .  ". " .
             translate("The subject is") . " \"" . $name . "\"\n\n" .
             translate("The description is") . " \"" . $description . "\"\n" .
             translate("Date") . ": " . date_to_str ( $fmtdate ) . "\n" .
-            ( ( empty ( $hour ) && empty ( $minute ) ) ? "" :
+            ( ( empty ( $user_hour ) && empty ( $minute ) ) ? "" :
             translate("Time") . ": " .
-            display_time ( ( $hour * 10000 ) + ( $minute * 100 ) ) . "\n" ) .
+            display_time ( ( $user_hour * 10000 ) + ( $minute * 100 ), true ) . "\n" ) .
             translate("Please look on") . " " . translate($application_name) . " " .
             ( $require_approvals == "Y" ?
             translate("to accept or reject this appointment") :
@@ -507,10 +631,11 @@ if ( empty ( $error ) ) {
             $url = $server_url .  "view_entry.php?id=" .  $id;
             $msg .= "\n\n" . $url;
           }
-          if ( strlen ( $from ) )
+          if ( strlen ( $from ) ) {
             $extra_hdrs = "From: $from\r\nX-Mailer: " . translate($application_name);
-          else
+          } else {
             $extra_hdrs = "X-Mailer: " . translate($application_name);
+          }
           mail ( $tempemail,
             translate($application_name) . " " . translate("Notification") . ": " . $name,
             html_to_8bits ($msg), $extra_hdrs );
@@ -528,10 +653,11 @@ if ( empty ( $error ) ) {
         $sql = "INSERT INTO webcal_entry_ext_user " .
           "( cal_id, cal_fullname, cal_email ) VALUES ( " .
           "$id, '$ext_names[$i]', ";
-        if ( strlen ( $ext_emails[$i] ) )
+        if ( strlen ( $ext_emails[$i] ) ) {
           $sql .= "'$ext_emails[$i]' )";
-        else
+        } else {
           $sql .= "NULL )";
+        }
         if ( ! dbi_query ( $sql ) ) {
           $error = translate("Database error") . ": " . dbi_error ();
         }
@@ -540,11 +666,14 @@ if ( empty ( $error ) ) {
         if ( $external_notifications == "Y" && $send_email != "N" &&
           strlen ( $ext_emails[$i] ) > 0 ) {
           $fmtdate = sprintf ( "%04d%02d%02d", $year, $month, $day );
+          // Strip [\d] from duplicate Names before emailing
+          $ext_names[$i] = trim(preg_replace( '/\[[\d]]/', "", $ext_names[$i]) );
           $msg = translate("Hello") . ", " . $ext_names[$i] . ".\n\n";
-          if ( $newevent )
+          if ( $newevent ) {
             $msg .= translate("A new appointment has been made for you by");
-          else
+          } else {
             $msg .= translate("An appointment has been updated by");
+          }
           $msg .= " " . $login_fullname .  ". " .
             translate("The subject is") . " \"" . $name . "\"\n\n" .
             translate("The description is") . " \"" . $description . "\"\n" .
@@ -559,10 +688,11 @@ if ( empty ( $error ) ) {
             $url = $server_url .  "view_entry.php?id=" .  $id;
             $msg .= "\n\n" . $url;
           }
-          if ( strlen ( $from ) )
+          if ( strlen ( $from ) ) {
             $extra_hdrs = "From: $from\r\nX-Mailer: " . translate($application_name);
-          else
+          } else {
             $extra_hdrs = "X-Mailer: " . translate($application_name);
+          }
           mail ( $ext_emails[$i],
             translate($application_name) . " " .
             translate("Notification") . ": " . $name,
@@ -625,30 +755,33 @@ if ( empty ( $error ) ) {
     }
     if ( strlen ( $sql ) && empty ( $error ) ) {
       //echo "SQL: $sql<BR>\n";
-      if ( ! dbi_query ( $sql ) )
+      if ( ! dbi_query ( $sql ) ) {
         $error = translate("Database error") . ": " . dbi_error ();
+      }
     }
   }
 
   // clearly, we want to delete the old repeats, before inserting new...
   if ( empty ( $error ) ) {
-    if ( ! dbi_query ( "DELETE FROM webcal_entry_repeats WHERE cal_id = $id") )
+    if ( ! dbi_query ( "DELETE FROM webcal_entry_repeats WHERE cal_id = $id") ) {
       $error = translate("Database error") . ": " . dbi_error ();
+    }
     // add repeating info
-    if ( strlen ( $rpt_type ) && $rpt_type != 'none' ) {
+    if ( ! empty ( $rpt_type ) && strlen ( $rpt_type ) && $rpt_type != 'none' ) {
       $freq = ( $rpt_freq ? $rpt_freq : 1 );
-      if ( $rpt_end_use )
+      if ( ! empty ( $rpt_end_use  ) ) {
         $end = sprintf ( "%04d%02d%02d", $rpt_year, $rpt_month, $rpt_day );
-      else
+      } else {
         $end = 'NULL';
+      }
       if ($rpt_type == 'weekly') {
-        $days = ( $rpt_sun ? 'y' : 'n' )
-          . ( $rpt_mon ? 'y' : 'n' )
-          . ( $rpt_tue ? 'y' : 'n' )
-          . ( $rpt_wed ? 'y' : 'n' )
-          . ( $rpt_thu ? 'y' : 'n' )
-          . ( $rpt_fri ? 'y' : 'n' )
-          . ( $rpt_sat ? 'y' : 'n' );
+        $days = ( empty( $rpt_sun )  ? 'n' : 'y' )
+          . (  empty( $rpt_mon )  ? 'n' : 'y' )
+          . (  empty( $rpt_tue )  ? 'n' : 'y' )
+          . (  empty( $rpt_wed )  ? 'n' : 'y' )
+          . (  empty( $rpt_thu )  ? 'n' : 'y' )
+          . (  empty( $rpt_fri )  ? 'n' : 'y' )
+          . (  empty( $rpt_sat )  ? 'n' : 'y' );
       } else {
         $days = "nnnnnnn";
       }
@@ -662,26 +795,13 @@ if ( empty ( $error ) ) {
   }
 }
 
-#print $msg; exit;
-
 // If we were editing this event, then go back to the last view (week, day,
 // month).  If this is a new event, then go to the preferred view for
 // the date range that this event was added to.
 if ( empty ( $error ) ) {
-  $last_view = get_last_view ();
-  if ( strlen ( $last_view ) && ! $newevent ) {
-    $url = $last_view;
-  } else {
-    $url = sprintf ( "%s.php?date=%04d%02d%02d",
-      $STARTVIEW, $year, $month, $day );
-  }
-  if ($is_assistant || $is_nonuser_admin)
-    $url .= (strpos($url, "?") === false ? "?" : "&") . "user=$user";
-  else if ( ! empty ( $user ) )
-    $url .= (strpos($url, "?") === false ? "?" : "&") . "user=$user";
-//echo "last_view: $last_view<br>\n"; exit;
-//echo "URL: $url<br>\n"; exit;
-  do_redirect ( $url );
+  $xdate = sprintf ( "%04d%02d%02d", $year, $month, $day );
+  $user_args = ( empty ( $user ) ? '' : "user=$user" );
+  send_to_preferred_view ( $xdate, $user_args );
 }
 
 print_header();
@@ -691,9 +811,9 @@ if ( strlen ( $conflicts ) ) {
 
 <?php etranslate("Your suggested time of")?> <span style="font-weight:bold;">
 <?php
-  if ( ! empty ( $allday ) && $allday == "Y" )
+  if ( ! empty ( $allday ) && $allday == "Y" ) {
     etranslate("All day event");
-  else {
+  } else {
     $time = sprintf ( "%d%02d00", $hour, $minute );
     echo display_time ( $time );
     if ( $duration > 0 )
@@ -707,17 +827,21 @@ if ( strlen ( $conflicts ) ) {
 <?php
 // user can confirm conflicts
   echo "<form name=\"confirm\" method=\"post\">\n";
-  while (list($xkey, $xval)=each($HTTP_POST_VARS)) {
+  if ( ! is_array ( $_POST ) && is_array ( $HTTP_POST_VARS ) )
+    $_POST = $HTTP_POST_VARS;
+  while (list($xkey, $xval)=each($_POST)) {
     if (is_array($xval)) {
       $xkey.="[]";
       while (list($ykey, $yval)=each($xval)) {
         if (get_magic_quotes_gpc())
           $yval = stripslashes($yval);
+        $yval = htmlentities  ( $yval );
         echo "<input type=\"hidden\" name=\"$xkey\" value=\"$yval\" />\n";
       }
     } else {
       if (get_magic_quotes_gpc())
         $xval = stripslashes($xval);
+      $xval = htmlentities ( $xval );
       echo "<input type=\"hidden\" name=\"$xkey\" value=\"$xval\" />\n";
     }
   }
@@ -732,7 +856,8 @@ if ( strlen ( $conflicts ) ) {
       "value=\"" . translate("Save") . "\" /></td>\n";
   }
 ?>
-   <td><input type="button" value="<?php etranslate("Cancel")?>" onclick="history.back()" /><td>
+   <td><input type="button" value="<?php etranslate("Cancel")?>" 
+onclick="history.back()" /><td>
  </tr>
 </table>
 </form>
