@@ -1,6 +1,6 @@
 <?php
 /*
- * $Id: export_handler.php,v 1.27 2004/11/22 16:34:17 cknudsen Exp $
+ * $Id: export_handler.php,v 1.29.2.4 2005/11/28 22:22:51 cknudsen Exp $
  *
  * Description:
  *	Handler for exporting webcalendar events to various formats.
@@ -29,7 +29,7 @@ function export_get_event_entry($id) {
     $endyear,$endmonth,$endday,$modyear,$modmonth,$modday,$login;
   global $DISPLAY_UNAPPROVED, $layers;
 
-  // We exporting repeating events only with the pilot-datebook CSV format
+  // We export repeating events only with the pilot-datebook CSV format
   $sql = "SELECT webcal_entry.cal_id, webcal_entry.cal_name " .
     ", webcal_entry.cal_priority, webcal_entry.cal_date " .
     ", webcal_entry.cal_time " .
@@ -42,7 +42,7 @@ function export_get_event_entry($id) {
   if ($id == "all") {
       $sql .= "WHERE webcal_entry.cal_id = webcal_entry_user.cal_id AND " .
 	" ( webcal_entry_user.cal_login = '" . $login . "'";
-      if ( $user && $user != $login ) {
+      if ( ! empty ( $user ) && $user != $login ) {
         $sql .= " OR webcal_entry_user.cal_login = '$user'";
       } else if ( $include_layers && $layers ) {
         foreach ( $layers as $layer ) {
@@ -67,7 +67,7 @@ function export_get_event_entry($id) {
         // TODO: add support for user in URL so we can export from other
         // calendars, particularly non-user calendars.
 	//"webcal_entry_user.cal_id = '$id'";
-      if ( $user && $user != $login ) {
+      if ( ! empty ( $user )  && $user != $login ) {
         $sql .= " OR webcal_entry_user.cal_login = '$user'";
       } else if ( $layers ) {
         foreach ( $layers as $layer ) {
@@ -176,7 +176,11 @@ function export_fold_lines($string, $encoding="none", $limit=76) {
 function export_get_attendee($id, $export) {
   global $login;
 
-  $request = "SELECT cal_login, cal_status FROM webcal_entry_user WHERE cal_id = '$id'";
+  $request = "SELECT webcal_entry_user.cal_login, webcal_entry_user.cal_status, " .
+    " webcal_entry.cal_create_by " . 
+    "FROM webcal_entry_user LEFT JOIN  webcal_entry " .
+    " ON webcal_entry_user.cal_id = webcal_entry.cal_id " .
+    " WHERE webcal_entry_user.cal_id = '$id' AND webcal_entry_user.cal_status <> 'D'";
 
   $att_res =  dbi_query($request);
 
@@ -194,7 +198,8 @@ function export_get_attendee($id, $export) {
   $count = 0;
 
   while (list($key,$row) = each($entry_array)) {
-      $request = "SELECT cal_firstname, cal_lastname, cal_email FROM webcal_user where cal_login = '". $row[0] . "'";
+      $request = "SELECT cal_firstname, cal_lastname, cal_email, cal_login " .
+        " FROM webcal_user where cal_login = '". $row[0] . "'";
 
       $user_res = dbi_query($request);
 
@@ -204,7 +209,7 @@ function export_get_attendee($id, $export) {
 
 	if (count($user) > 0) {
 	  $attendee[$count] = "ATTENDEE;ROLE=";
-	  $attendee[$count] .=	($row[0] == $login) ? "OWNER;" : "ATTENDEE;";
+	  $attendee[$count] .=	($row[2] == $user[3]) ? "OWNER;" : "ATTENDEE;";
 	  $attendee[$count] .= "STATUS=";
 
 	  switch ($row[1]) {
@@ -631,6 +636,7 @@ function generate_uid() {
 
 
 function export_vcal ($id) {
+  global $prodid;
   header ( "Content-Type: text/x-vcalendar" );
   //header ( "Content-Type: text/plain" );
 
@@ -779,10 +785,10 @@ function export_ical ($id) {
 	echo "$value\r\n";
 
       $name = preg_replace("/\r/", "", $name);
-      $name = preg_replace("/\n/", "\\n", $name);
+      //$name = preg_replace("/\n/", "\\n", $name); //PER RFC2445
       $name = preg_replace("/\\\\/", "\\\\\\", $name); // ??
       $description = preg_replace("/\r/", "", $description);
-      $description = preg_replace("/\n/", "\\n", $description);
+      //$description = preg_replace("/\n/", "\\n", $description); //PER RFC2445
       $description = preg_replace("/\\\\/", "\\\\\\", $description); // ??
 
       /* SUMMARY of the event (folded to 76 char) */
@@ -1006,19 +1012,29 @@ function transmit_header ( $mime, $file ) {
 /*** Let's go ***/
 /*******************************************/
 
-$id = $HTTP_POST_VARS["id"];
-$format = $HTTP_POST_VARS["format"];
-$use_all_dates = $HTTP_POST_VARS["use_all_dates"];
-$include_layers = $HTTP_POST_VARS["include_layers"];
-$fromyear = $HTTP_POST_VARS["fromyear"];
-$frommonth = $HTTP_POST_VARS["frommonth"];
-$fromday = $HTTP_POST_VARS["fromday"];
-$endyear = $HTTP_POST_VARS["endyear"];
-$endmonth = $HTTP_POST_VARS["endmonth"];
-$endday = $HTTP_POST_VARS["endday"];
-$modyear = $HTTP_POST_VARS["modyear"];
-$modmonth = $HTTP_POST_VARS["modmonth"];
-$modday = $HTTP_POST_VARS["modday"];
+$id = getIntValue  ( 'id', true );
+$format = getValue  ( 'format' );
+if ( $format != 'ical' && $format != 'vcal' && $format != 'pilot-csv' &&
+  $format != 'pilot-text' )
+  die_miserable_death ( "Invalid format '" . $format . "'" );
+
+$use_all_dates = getPostValue  ( 'use_all_dates' );
+if ( $use_all_dates != 'y' )
+  $use_all_dates = '';
+
+$include_layers = getPostValue  ( 'include_layers' );
+if ( $include_layers != 'y' )
+ $include_layers = '';
+
+$fromyear = getIntValue  ( 'fromyear', true );
+$frommonth = getIntValue  ( 'frommonth', true );
+$fromday = getIntValue  ( 'fromday', true );
+$endyear = getIntValue  ( 'endyear', true );
+$endmonth = getIntValue  ( 'endmonth', true );
+$endday = getIntValue  ( 'endday', true );
+$modyear = getIntValue  ( 'modyear', true );
+$modmonth = getIntValue  ( 'modmonth', true );
+$modday = getIntValue  ( 'modday', true );
 
 mt_srand((float) microtime()*1000000);
 
