@@ -1,9 +1,9 @@
 <script type="text/javascript">
 <!-- <![CDATA[
 function schedule_event (h,m) {
-  document.forms[0].hour.value = h;
-  document.forms[0].minute.value = m;
-  document.forms[0].submit ();
+  document.schedule.hour.value = h;
+  document.schedule.minute.value = m;
+  document.schedule.submit ();
   return true;
 }
 //]]> -->
