@@ -1,20 +1,22 @@
 <?php
 /*
- * $Id: index.php,v 1.11 2004/12/08 02:29:07 cknudsen Exp $
+ * $Id: index.php,v 1.17.2.2 2005/08/09 15:20:57 cknudsen Exp $
  *
  * Page Description:
- *	Main page for install/config of db settings.
- *	This page is used to create/update includes/settings.php.
+ * Main page for install/config of db settings.
+ * This page is used to create/update includes/settings.php.
  *
  * Input Parameters:
- *	None
+ * None
  *
  * Security:
- *	The first time this page is accessed, there are no security
- *	precautions.   The user is prompted to generate a config password.
- *	From then on, users must know this password to make any changes
- *	to the settings in settings.php./
+ * The first time this page is accessed, there are no security
+ * precautions.   The user is prompted to generate a config password.
+ * From then on, users must know this password to make any changes
+ * to the settings in settings.php./
  *
+ * TODO:
+ * Add translations to this page.
  */
 include_once '../includes/php-dbi.php';
 
@@ -23,32 +25,48 @@ $fileDir = "../includes";
 
 // Get value from POST form
 function getPostValue ( $name ) {
-  if ( ! empty ( $_POST[$name] ) )
+  if ( ! empty ( $_POST[$name] ) ) {
     return $_POST[$name];
-  if ( ! isset ( $HTTP_POST_VARS ) )
+  }
+  if ( ! isset ( $HTTP_POST_VARS ) ) {
     return null;
-  if ( ! isset ( $HTTP_POST_VARS[$name] ) )
+  }
+  if ( ! isset ( $HTTP_POST_VARS[$name] ) ) {
     return null;
+  }
   return ( $HTTP_POST_VARS[$name] );
 }
 
 
 // Get value from GET form
 function getGetValue ( $name ) {
-  if ( ! empty ( $_GET[$name] ) )
+  if ( ! empty ( $_GET[$name] ) ) {
     return $_GET[$name];
-  if ( ! isset ( $HTTP_GET_VARS ) )
+  }
+  if ( ! isset ( $HTTP_GET_VARS ) ) {
     return null;
-  if ( ! isset ( $HTTP_GET_VARS[$name] ) )
+  }
+  if ( ! isset ( $HTTP_GET_VARS[$name] ) ) {
     return null;
+  }
   return ( $HTTP_GET_VARS[$name] );
 }
 
+function get_php_setting ( $val ) {
+  $setting = ini_get ( $val );
+  if ( $setting == '1' || $setting == 'ON' )
+    return 'ON';
+  else
+    return 'OFF';
+}
+
+
+
 
 
 // First pass at settings.php.
 // We need to read it first in order to get the md5 password.
-$fd = @fopen ( $file, "rb", true );
+$fd = @fopen ( $file, "rb", false );
 $settings = array ();
 $password = '';
 $forcePassword = false;
@@ -56,7 +74,7 @@ if ( ! empty ( $fd ) ) {
   while ( ! feof ( $fd ) ) {
     $buffer = fgets ( $fd, 4096 );
     $buffer = trim ( $buffer, "\r\n " );
-    if ( preg_match ( "/^(\S+):\s*(.*)/", $buffer, $matches ) ) {
+    if ( preg_match ( "/^(\S+):\s*(.*)/", $buffer,  $matches ) ) {
       if ( $matches[1] == "install_password" ) {
         $password = $matches[2];
         $settings['install_password'] = $password;
@@ -73,6 +91,13 @@ if ( ! empty ( $fd ) ) {
 session_start ();
 $doLogin = false;
 
+// Handle "Logout" button
+if ( 'logout' == getGetValue ( 'action' ) ) {
+  session_destroy ();
+  Header ( "Location: index.php" );
+  exit;
+}
+
 // If password already exists, check for session.
 if ( file_exists ( $file ) && ! empty ( $password ) &&
   ( empty ( $_SESSION['validuser'] ) ||
@@ -117,15 +142,15 @@ if ( file_exists ( $file ) && $forcePassword && ! empty ( $pwd1 ) ) {
     echo "Passwords do not match!<br/>\n";
     exit;
   }
-  $fd = fopen ( $file, "a+", true );
+  $fd = fopen ( $file, "a+b", false );
   if ( empty ( $fd ) ) {
     echo "<html><body>Unable to write password to settings.php file\n" .
       "</body></html>";
     exit;
   }
-  fwrite ( $fd, "<?php\n" );
-  fwrite ( $fd, "install_password: " . md5($pwd1) . "\n" );
-  fwrite ( $fd, "?>\n" );
+  fwrite ( $fd, "<?php\r\n" );
+  fwrite ( $fd, "install_password: " . md5($pwd1) . "\r\n" );
+  fwrite ( $fd, "?>\r\n" );
   fclose ( $fd );
   ?>
     <html><head><title>Password Updated</title>
@@ -142,34 +167,56 @@ if ( file_exists ( $file ) && $forcePassword && ! empty ( $pwd1 ) ) {
 // If so, just test the connection, show the result and exit.
 $action = getGetValue ( "action" );
 if ( ! empty ( $action ) && $action == "dbtest" ) {
-  // TODO: restrict access here also...
-  $db_persistent = false; ( 'db_type' );
-  $db_type = getGetValue ( 'db_type' );
-  $db_host = getGetValue ( 'db_host' );
-  $db_database = getGetValue ( 'db_database' );
-  $db_login = getGetValue ( 'db_login' );
-  $db_password = getGetValue ( 'db_password' );
+  if ( ! empty ( $_SESSION['validuser'] ) ) {
+    $db_persistent = false;
+    $db_type = getGetValue ( 'db_type' );
+    $db_host = getGetValue ( 'db_host' );
+    $db_database = getGetValue ( 'db_database' );
+    $db_login = getGetValue ( 'db_login' );
+    $db_password = getGetValue ( 'db_password' );
 
-  echo "<html><head><title>WebCalendar: Db Connection Test</title>\n" .
-    "</head><body style=\"background-color: #fff;\">\n";
-  echo "<p><b>Connection Result:</b></p><blockquote>";
+    echo "<html><head><title>WebCalendar: Db Connection Test</title>\n" .
+      "</head><body style=\"background-color: #fff;\">\n";
+    echo "<p><b>Connection Result:</b></p><blockquote>";
 
-  $c = dbi_connect ( $db_host, $db_login,
-    $db_password, $db_database );
+    $c = dbi_connect ( $db_host, $db_login,
+      $db_password, $db_database );
 
-  if ( $c ) {
-    echo "<span style=\"color: #0f0;\">Success</span></blockquote>";
-  } else {
-    echo "<span style=\"color: #0f0;\">Failure</span</blockquote>";
-    echo "<br/><br/><b>Reason:</b><blockquote>" . dbi_error () .
-      "</blockquote>\n";
+    if ( $c ) {
+      echo "<span style=\"color: #0f0;\">Success</span></blockquote>";
+      $_SESSION['db_success'] = true;
+      // TODO: update the text in the main window to indicate success
+    } else {
+      echo "<span style=\"color: #0f0;\">Failure</span</blockquote>";
+      echo "<br/><br/><b>Reason:</b><blockquote>" . dbi_error () .
+        "</blockquote>\n";
+    }
+    echo "<br/><br/><br/><div align=\"center\"><form><input align=\"middle\" type=\"button\" onclick=\"window.close()\" value=\"Close\" /></form></div>\n";
+    echo "</p>";
+    echo "<script language=\"JavaScript\" type=\"text/javascript\">\n";
+    echo "<!-- <![CDATA[\n";
+    echo "window.opener.show_db_status ( " .
+      ( $c ? "true" : "false" ) . " );\n";
+    echo "//]]> -->\n</script>\n";
+    echo "</body></html>\n";
+  } else { // Not valid user
+    echo "You are not authorized.";
+    // etranslate ( "You are not authorized" );  
   }
-  echo "<br/><br/><br/><div align=\"center\"><form><input align=\"middle\" type=\"button\" onclick=\"window.close()\" value=\"Close\" /></form></div>\n";
-  echo "</p></body></html>\n";
   exit;
 }
 
-
+// Is this a call to phpinfo()?
+$action = getGetValue ( "action" );
+if ( ! empty ( $action ) && $action == "phpinfo" ) {
+  if ( ! empty ( $_SESSION['validuser'] ) ) {
+    phpinfo();
+  } else {
+    echo "You are not authorized.";
+    // etranslate ( "You are not authorized" );
+  }
+  exit;
+}
 
 
 $exists = file_exists ( $file );
@@ -179,7 +226,7 @@ if ( $exists ) {
 } else {
   // check to see if we can create a new file.
   $testFile = $fileDir . "/installTest.dat";
-  $testFd = @fopen ( $testFile, "w+t", true );
+  $testFd = @fopen ( $testFile, "w+b", false );
   if ( file_exists ( $testFile ) ) {
     $canWrite = true;
   }
@@ -203,6 +250,10 @@ if ( empty ( $x ) ) {
     $settings['readonly'] = 'false';
     $settings['user_inc'] = 'user.php';
     $settings['install_password'] = '';
+    $settings['single_user_login'] = '';
+    $settings['use_http_auth'] = 'false';
+    $settings['single_user'] = 'false';
+    $settings['user_inc'] = 'user.php';
   }
 } else {
   $settings['db_type'] = getPostValue ( 'form_db_type' );
@@ -234,20 +285,20 @@ if ( empty ( $x ) ) {
   } else {
     $onload .= "alert('Your settings have been saved.\\n\\n');";
   }
-  $fd = @fopen ( $file, "w+t", true );
+  $fd = @fopen ( $file, "w+b", false );
   if ( empty ( $fd ) ) {
-    if ( file_exists ( $fd ) ) {
+    if ( file_exists ( $file ) ) {
       $onload = "alert('Error: unable to write to file $file\\nPlease change the file permissions of this file.');";
     } else {
       $onload = "alert('Error: unable to write to file $file\\nPlease change the file permissions of your includes directory\\nto allow writing by other users.');";
     }
   } else {
-    fwrite ( $fd, "<?php\n" );
-    fwrite ( $fd, "# updated via install/index.php on " . date("r") . "\n" );
+    fwrite ( $fd, "<?php\r\n" );
+    fwrite ( $fd, "# updated via install/index.php on " . date("r") . "\r\n" );
     foreach ( $settings as $k => $v ) {
-      fwrite ( $fd, $k . ": " . $v . "\n" );
+      fwrite ( $fd, $k . ": " . $v . "\r\n" );
     }
-    fwrite ( $fd, "# end settings.php\n?>\n" );
+    fwrite ( $fd, "# end settings.php\r\n?>\r\n" );
     fclose ( $fd );
     // Change to read/write by us only (only applies if we created file)
     // and read-only by all others.  Would be nice to make it 600, but
@@ -258,7 +309,7 @@ if ( empty ( $x ) ) {
 }
 
 
-$fd = @fopen ( $file, "rb", true );
+$fd = @fopen ( $file, "rb", false );
 if ( ! empty ( $fd ) ) {
   while ( ! feof ( $fd ) ) {
     $buffer = fgets ( $fd, 4096 );
@@ -270,6 +321,7 @@ if ( ! empty ( $fd ) ) {
     if ( preg_match ( "/^\?>/", $buffer ) ) // end php code
       continue;
     if ( preg_match ( "/(\S+):\s*(.*)/", $buffer, $matches ) ) {
+// echo $matches[1] . " " .  $matches[2] . "<br>";
       $settings[$matches[1]] = $matches[2];
       //echo "settings $matches[1] => $matches[2] <br>";
     }
@@ -277,24 +329,16 @@ if ( ! empty ( $fd ) ) {
   fclose ( $fd );
 }
 
-
-// Attempt a db connection
-$connectSuccess = false;
-$db_type = $settings['db_type'];
-$db_persistent = false;
-$c = @dbi_connect ( $settings['db_host'], $settings['db_login'],
-  $settings['db_password'], $settings['db_database'] );
-if ( $c ) {
-  $connectSuccess = true;
-}
-
-
+echo '<?xml version="1.0" encoding="UTF-8"?>' . "\n";
 ?>
-<html>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "DTD/xhtml1-transitional.dtd">
+<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
 <head><title>WebCalendar Database Setup</title>
+<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
 <?php include "../includes/js/visible.php"; ?>
-<script language="JavaScript">
-
+<script language="JavaScript" type="text/javascript">
+<!-- <![CDATA[
+<?php   if ( ! empty ( $_SESSION['validuser'] ) ) { ?>
 function testSettings () {
   var url;
   var form = document.dbform;
@@ -307,6 +351,14 @@ function testSettings () {
   //alert ( "URL:\n" + url );
   window.open ( url, "wcDbTest", "width=400,height=350,resizable=yes,scrollbars=yes" );
 }
+function testPHPInfo () {
+  var url;
+  var form = document.phpinfo;
+  url = "index.php?action=phpinfo";
+  //alert ( "URL:\n" + url );
+  window.open ( url, "wcTestPHPInfo", "width=800,height=600,resizable=yes,scrollbars=yes" );
+}
+<?php } ?>
 function validate(form)
 {
   var form = document.dbform;
@@ -332,6 +384,16 @@ function auth_handler () {
   }
 }
 
+function show_db_status ( success ) {
+  if ( success ) {
+    makeVisible ( "db_success" );
+    makeInvisible ( "no_db_success" );
+  } else {
+    makeInvisible ( "db_success" );
+    makeVisible ( "no_db_success" );
+  }
+}
+ //]]> -->
 </script>
 <style type="text/css">
 body {
@@ -366,6 +428,12 @@ li {
 doc.li {
   margin-top: 5px;
 }
+.recommended {
+  color: green;
+}
+.notrecommended {
+  color: red;
+}
 </style>
 </head>
 <body onload="<?php echo $onload;?>">
@@ -384,7 +452,7 @@ doc.li {
 <div class="main">
 <h2>WebCalendar Database Setup</h2>
 
-<p>Current Status:</p>
+<p><b>Current Status:</b></p>
 <ul>
 
 <li>Supported databases for your PHP installation:
@@ -402,6 +470,8 @@ doc.li {
     $dbs[] = "odbc";
   if ( function_exists ( "ibase_pconnect" ) )
     $dbs[] = "ibase";
+  if ( function_exists ( "mssql_pconnect" ) )
+    $dbs[] = "mssql";
   for ( $i = 0; $i < count ( $dbs ); $i++ ) {
     if ( $i ) echo ", ";
     echo $dbs[$i];
@@ -409,22 +479,20 @@ doc.li {
   }
 ?>
 </li>
-<?php if ( ! $forcePassword ) { ?>
-  <?php if ( $connectSuccess ) { ?>
-  <li> Your current database settings are able to
+<?php if ( ! empty ( $_SESSION['db_success'] ) && $_SESSION['db_success']  ) { ?>
+<li id="db_success"> Your current database settings are able to
   access the database.</li>
-  <?php } else { ?>
-  <li> Your current database settings are <b>not</b> able to
+<li id="no_db_success" style="visibility: hidden;"> Your current database settings are <b>not</b> able to
+  access the database or have not yet been tested.</li>
+<?php } else { ?>
+<li id="no_db_success"> Your current database settings are <b>not</b> able to
+  access the database or have not yet been tested.</li>
+<li id="db_success" style="visibility: hidden;"> Your current database settings are able to
   access the database.</li>
-  <?php } ?>
 <?php } ?>
-
 <?php if ( empty ( $password ) ) { ?>
   <li> You have not set a password for this page. </li>
 <?php } ?>
-
-
-
 <?php if ( $exists && ! $canWrite ) { ?>
 <li><b>Error:</b>
 The file permissions of <tt>settings.php</tt> are set so
@@ -435,9 +503,7 @@ file to use this script:
 <?php echo realpath ( $file ); ?>
 </tt></blockquote>
 </li>
-
 <?php } else if ( ! $exists && ! $canWrite ) { ?>
-
 <li><b>Error:</b>
 The file permissions of the <tt>includes</tt> directory are set so
 that this script does not have permission to create a new file
@@ -448,13 +514,10 @@ to use this script:
 <?php echo realpath ( $fileDir ); ?>
 </tt></blockquote>
 </li>
-
 <?php } else { ?>
-
   <?php if ( ! file_exists ( $file ) ) { ?>
   <li>You have not created a <tt>settings.php</tt> file yet.</li>
   <?php } ?>
-
 <?php if ( empty ( $PHP_AUTH_USER ) ) { ?>
 <li>HTTP-based authentication was not detected.
 You will need to reconfigure your web server if you wish to
@@ -470,19 +533,22 @@ You should select "Web Server" from the list of
 
 </ul>
 
+<table>  <tr><td valign="top">
 <?php if ( $doLogin ) { ?>
-  <form action="index.php" method="POST" name="dblogin">
+  <form action="index.php" method="post" name="dblogin">
+
   <p>Please enter the password.</p>
     <br /><br />
   </p>
-  <table border="0">
+  <table >
   <tr><th colspan="2" class="header">Enter Password</th></tr>
   <tr><th>Password:</th><td><input name="password" type="password" /></td></tr>
   <tr><td colspan="2" align="center"><input type="submit" value="Login" /></td></tr>
   </table><br />
   </form>
+  </td></tr></table>
 <?php } else if ( $forcePassword ) { ?>
-  <form action="index.php" method="POST" name="dbpassword">
+  <form action="index.php" method="post" name="dbpassword">
   <p>You have not set a password for access to this page yet.
      Please set the password.
     <br /><br />
@@ -494,8 +560,9 @@ You should select "Web Server" from the list of
   <tr><td colspan="2" align="center"><input type="submit" value="Set Password" /></td></tr>
   </table><br />
   </form>
+  </td></tr></table>
 <?php } else { ?>
-<form action="index.php" method="POST" name="dbform">
+<form action="index.php" method="post" name="dbform">
 
 <table>
 <tr><th class="header" colspan="2">Database Settings</th></tr>
@@ -508,6 +575,11 @@ You should select "Web Server" from the list of
     echo "<option value=\"mysql\" " .
       ( $settings['db_type'] == 'mysql' ? " selected=\"selected\"" : "" ) .
       "> MySQL </option>\n";
+      
+  if ( ! empty ( $supported['mysqli'] ) )
+    echo "<option value=\"mysqli\" " .
+      ( $settings['db_type'] == 'mysqli' ? " selected=\"selected\"" : "" ) .
+      "> MySQL (Improved)</option>\n";
 
   if ( ! empty ( $supported['oracle'] ) )
     echo "<option value=\"oracle\" " .
@@ -528,6 +600,11 @@ You should select "Web Server" from the list of
     echo "<option value=\"ibase\" " .
       ( $settings['db_type'] == 'ibase' ? " selected=\"selected\"" : "" ) .
       "> Interbase </option>\n";
+
+  if ( ! empty ( $supported['mssql'] ) )
+    echo "<option value=\"mssql\" " .
+      ( $settings['db_type'] == 'mssql' ? " selected=\"selected\"" : "" ) .
+      "> MS SQL Server </option>\n";
 ?>
 </select>
 </td></tr>
@@ -546,31 +623,35 @@ You should select "Web Server" from the list of
 
 <tr><td class="prompt">Connection Persistence:</td>
 <td><input name="form_db_persistent" value="true" type="radio"
-  <?php if ( $settings['db_persistent'] == 'true' )
-          echo " checked=\"checked\"";
-  ?> >Enabled
+  <?php echo ( $settings['db_persistent'] == 'true' )? " checked=\"checked\"" : "";
+  ?> />Enabled
   &nbsp;&nbsp;&nbsp;&nbsp;
   <input name="form_db_persistent" value="false" type="radio"
-  <?php if ( $settings['db_persistent'] != 'true' )
-          echo " checked=\"checked\"";
-  ?> >Disabled
+  <?php echo ( $settings['db_persistent'] != 'true' )? " checked=\"checked\"" : "";
+  ?> />Disabled
   </td></tr>
-
+<?php if ( ! empty ( $_SESSION['validuser'] ) ) { ?>
 <tr><td colspan="2" align="center">
 <input name="action" type="button" value="Test Settings"
   onclick="testSettings()" />
 </td></tr>
-
+<?php } else { ?>
+<tr><th class="header" colspan="2">
+<p>You must save before proceeding.</p>
+</th></tr>
+<?php } ?>
 </table>
 
-<br/><br/>
-
-<table>
-<tr><th class="header" colspan="2">Application Settings</th></tr>
-
-<tr><td class="prompt">User Authentication:</td>
-<td>
-<select name="form_user_inc" onchange="auth_handler()">
+</td>
+<td valign="top">
+  <table width="100%">
+    <tr>
+      <th class="header" colspan="2" >Application Settings</th>
+    </tr>
+    <tr>
+      <td class="prompt">User Authentication:</td>
+      <td>
+        <select name="form_user_inc" onchange="auth_handler()">
 <?php
   echo "<option value=\"user.php\" " .
     ( $settings['user_inc'] == 'user.php' && $settings['use_http_auth'] != 'true' ? " selected=\"selected\"" : "" ) .
@@ -579,7 +660,7 @@ You should select "Web Server" from the list of
   echo "<option value=\"http\" " .
     ( $settings['user_inc'] == 'user.php' && $settings['use_http_auth'] == 'true' ? " selected=\"selected\"" : "" ) .
     "> Web Server " .
-    ( empty ( $PHP_AUTH_USER ) ? "(not detected)" : "(not detected)" ) .
+    ( empty ( $PHP_AUTH_USER ) ? "(not detected)" : "(detected)" ) .
     "</option>\n";
 
   echo "<option value=\"user-ldap.php\" " .
@@ -592,42 +673,77 @@ You should select "Web Server" from the list of
 
   echo "<option value=\"none\" " .
     ( $settings['user_inc'] == 'user.php' && $settings['single_user'] == 'true' ? " selected=\"selected\"" : "" ) .
-    "> None (Single-User) </option>\n";
+    "> None (Single-User) </option>\n</select>";
 ?>
-</td></tr>
-
-<tr id="singleuser"><td class="prompt">&nbsp;&nbsp;&nbsp;Single-User Login:</td>
-<td><input name="form_single_user_login" size="20" value="<?php echo $settings['single_user_login'];?>" /></td></tr>
-
-<tr><td class="prompt">Read-Only:</td>
-<td><input name="form_readonly" value="true" type="radio"
-  <?php if ( $settings['readonly'] == 'true' )
-          echo " checked=\"checked\"";
-  ?> >Yes
+        </td>
+      </tr>
+      <tr id="singleuser">
+        <td class="prompt">&nbsp;&nbsp;&nbsp;Single-User Login:</td>
+        <td>
+          <input name="form_single_user_login" size="20" value="<?php echo $settings['single_user_login'];?>" /></td>
+      </tr>
+      <tr>
+        <td class="prompt">Read-Only:</td>
+        <td>
+          <input name="form_readonly" value="true" type="radio"
+  <?php echo ( $settings['readonly'] == 'true' )? " checked=\"checked\"" : "";?> />Yes
   &nbsp;&nbsp;&nbsp;&nbsp;
   <input name="form_readonly" value="false" type="radio"
-  <?php if ( $settings['readonly'] != 'true' )
-          echo " checked=\"checked\"";
-  ?> >No
-  </td></tr>
+  <?php echo ( $settings['readonly'] != 'true' )? " checked=\"checked\"" : "";?> />No
+         </td>
+       </tr>
+    </table>
+<?php
 
-</table>
+$php_settings = array (
+  //array ('Safe Mode','safe_mode','OFF'),
+  array ('Magic Quotes GPC','magic_quotes_gpc','ON'),
+  array ('Register Globals','register_globals','ON'),
+  array ('Display Errors','display_errors','ON'),
+  //array ('Register Globals','register_globals','OFF'),
+  array ('File Uploads','file_uploads','ON'),
+);
 
-<br />
-<br />
+?>
+<table width="100%">
+<tr><th class="header"  colspan="2">PHP Settings</th></tr>
+<?php foreach ( $php_settings as $setting ) { ?>
+  <tr><td class="prompt"><?php echo $setting[0];?></td>
+  <?php
+    $class = ( get_php_setting ( $setting[1] ) == $setting[2] ) ?
+      'recommended' : 'notrecommended';
+    echo "<td class=\"$class\">";
+    echo get_php_setting ( $setting[1] );
+   ?>
+   </td></tr>
+<?php } ?>
 
+<?php if ( ! empty ( $_SESSION['validuser'] ) ) { ?>
+<tr><td  align="center" colspan="2"><input name="action" type="button" value="Detailed PHP Info"
+  onclick="testPHPInfo()" /></td></tr>
+<?php } ?>
+
+
+</table></td></tr>
+
+<tr><td align="center" colspan="2">
 <input name="action" type="button" value="Save Settings"
   onclick="return validate();" />
-  <?php if ( $connectSuccess ) { ?>
+  <?php if ( ! empty ( $_SESSION['db_success'] ) && $_SESSION['db_success']  && empty ( $dologin ) ) { ?>
     <input type="button" value="Launch WebCalendar"
       onclick="window.open('../index.php', 'webcalendar');" />
   <?php } ?>
+  <?php if ( ! empty ( $_SESSION['validuser'] ) ) { ?>
+    <input type="button" value="Logout"
+      onclick="document.location.href='index.php?action=logout'" />
+  <?php } ?>
 </form>
+</td></tr></table>
 <?php } ?>
 
 <?php } ?>
 </div>
-<div style="border-top: 1px solid #000; padding-bottom: 20px;">
+<div class="main">
 <p>
 <b>Documentation:</b>
 </p>
