@@ -129,10 +129,28 @@ print_header($INC);
 
 <tr><td class="tooltip" title="<?php etooltip("preferred-view-help");?>"><?php etranslate("Preferred view")?>:</td><td>
 <select name="pref_STARTVIEW">
-<option value="day" <?php if ( $prefarray["STARTVIEW"] == "day" ) echo " selected=\"selected\"";?>><?php etranslate("Day")?></option>
-<option value="week" <?php if ( $prefarray["STARTVIEW"] == "week" ) echo " selected=\"selected\"";?>><?php etranslate("Week")?></option>
-<option value="month" <?php if ( $prefarray["STARTVIEW"] == "month" ) echo " selected=\"selected\"";?>><?php etranslate("Month")?></option>
-<option value="year" <?php if ( $prefarray["STARTVIEW"] == "year" ) echo " selected=\"selected\"";?>><?php etranslate("Year")?></option>
+<?php
+// For backwards compatibility.  We used to store without the .php extension
+if ( $prefarray['STARTVIEW'] == 'month' || $prefarray['STARTVIEW'] == 'day' ||
+  $prefarray['STARTVIEW'] == 'week' || $prefarray['STARTVIEW'] == 'year' )
+  $prefarray['STARTVIEW'] .= '.php';
+?>
+<option value="day.php" <?php if ( $prefarray["STARTVIEW"] == "day.php" ) echo " selected=\"selected\"";?>><?php etranslate("Day")?></option>
+<option value="week.php" <?php if ( $prefarray["STARTVIEW"] == "week.php" ) echo " selected=\"selected\"";?>><?php etranslate("Week")?></option>
+<option value="month.php" <?php if ( $prefarray["STARTVIEW"] == "month.php" ) echo " selected=\"selected\"";?>><?php etranslate("Month")?></option>
+<option value="year.php" <?php if ( $prefarray["STARTVIEW"] == "year.php" ) echo " selected=\"selected\"";?>><?php etranslate("Year")?></option>
+<?php
+// Allow user to select a view also
+for ( $i = 0; $i < count ( $views ); $i++ ) {
+  $xurl = $views[$i]['url'];
+  echo "<option value=\"";
+  echo $xurl . "\" ";
+  $xurl_strip = str_replace ( "&amp;", "&", $xurl );
+  if ( $STARTVIEW == $xurl_strip )
+    echo "selected=\"selected\" ";
+  echo ">" . $views[$i]['cal_name'] . "</option>\n";
+}
+?>
 </select>
 </td></tr>
 
@@ -315,7 +333,7 @@ print_header($INC);
 <?php
 	echo "<option value=\"\"";
 	if ( empty ( $prefarray["CATEGORY_VIEW"] ) ) echo " selected=\"selected\"";
-	echo ">".translate('All')."</option>\n";
+	echo ">".translate("All")."</option>\n";
 	
 	if ( ! empty ( $categories ) ) {
 		foreach( $categories as $K => $V ){
@@ -379,13 +397,16 @@ print_header($INC);
 <table class="standard" cellspacing="1" cellpadding="2">
 <tr><th colspan="2"><?php etranslate("Subscribe/Publish")?></th></tr>
 <tr><td class="tooltipselect" title="<?php etooltip("allow-remote-subscriptions-help")?>"><?php etranslate("Allow remote subscriptions")?>:</td>
-  <td><label><input type="radio" name="pref_USER_PUBLISH_ENABLED" value="Y" <?php if ( $prefarray["USER_PUBLISH_ENABLED"] == "Y" ) echo " checked=\"checked\"";?> /> <?php etranslate("Yes")?></label> <label><input type="radio" name="pref_USER_PUBLISH_ENABLED" value="N" <?php if ( $prefarray["USER_PUBLISH_ENABLED"] != "Y" ) echo " checked=\"checked\"";?> /> <?php etranslate("No")?></label></td></tr>
+  <td><label><input type="radio" name="pref_USER_PUBLISH_ENABLED" value="Y" <?php if ( isset ( $prefarray["USER_PUBLISH_ENABLED"] ) && $prefarray["USER_PUBLISH_ENABLED"] == "Y" ) echo " checked=\"checked\"";?> /> <?php etranslate("Yes")?></label> <label><input type="radio" name="pref_USER_PUBLISH_ENABLED" value="N" <?php if ( empty ( $prefarray["USER_PUBLISH_ENABLED"] ) || $prefarray["USER_PUBLISH_ENABLED"] != "Y" ) echo " checked=\"checked\"";?> /> <?php etranslate("No")?></label></td></tr>
 <?php if ( ! empty ( $server_url ) ) { ?>
 <tr><td class="tooltipselect" title="<?php etooltip("remote-subscriptions-url-help")?>">&nbsp;&nbsp;&nbsp;&nbsp;<?php etranslate("URL")?>:</td>
   <td>
   <?php
-    echo htmlentities ( $server_url ) .
+    echo htmlspecialchars ( $server_url ) .
       "publish.php/" . ( $updating_public ? "public" : $login ) .  ".ics";
+    echo "<br/>\n";
+    echo htmlspecialchars ( $server_url ) .
+      "publish.php?user=" . ( $updating_public ? "public" : $login );
   ?></td></tr>
 <?php } /* $server_url */ ?>
 </table>
@@ -419,13 +440,13 @@ print_header($INC);
 		<input type="button" onclick="selectColor('pref_CELLBG')" value="<?php etranslate("Select")?>..." />
 	</td></tr>
 	<tr><td style="font-weight:bold;">
-		<label for="pref_today"><?php etranslate("Table cell background for current day")?>:<label></td><td>
+		<label for="pref_today"><?php etranslate("Table cell background for current day")?>:</label></td><td>
 		<input type="text" name="pref_TODAYCELLBG" id="pref_today" size="8" maxlength="7" value="<?php echo $prefarray["TODAYCELLBG"]; ?>" onkeyup="updateColor(this);" /></td><td style="background-color:<?php echo $prefarray["TODAYCELLBG"]?>; border-style: groove;">
 	&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td><td>
 		<input type="button" onclick="selectColor('pref_TODAYCELLBG')" value="<?php etranslate("Select")?>..." />
 	</td></tr>
 	<tr><td style="font-weight:bold;">
-		<label for="pref_wkend"><?php etranslate("Table cell background for weekends")?>:<label></td><td>
+		<label for="pref_wkend"><?php etranslate("Table cell background for weekends")?>:</label></td><td>
 		<input type="text" name="pref_WEEKENDBG" id="pref_wkend" size="8" maxlength="7" value="<?php echo $prefarray["WEEKENDBG"]; ?>" onkeyup="updateColor(this);" /></td><td style="background-color:<?php echo $prefarray["WEEKENDBG"]?>; border-style: groove;">
 	&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td><td>
 		<input type="button" onclick="selectColor('pref_WEEKENDBG')" value="<?php etranslate("Select")?>..." />
@@ -514,4 +535,4 @@ for ( $i = $wkstart; date ( "Ymd", $i ) <= date ( "Ymd", $monthend );
 
 <?php print_trailer(); ?>
 </body>
-</html>
\ No newline at end of file
+</html>
