@@ -1,34 +1,33 @@
 <?php
-
 /*
- * $Id: report.php,v 1.20 2004/11/06 02:43:37 musus Exp $
+ * $Id: report.php,v 1.27.2.3 2005/10/14 18:38:59 cknudsen Exp $
  *
  * Page Description:
- *	This page will either list all reports available to the current
- *	user (if report id not specified) or display a report (if the
- *	report id is specified).
+ * This page will either list all reports available to the current
+ * user (if report id not specified) or display a report (if the
+ * report id is specified).
  *
  * Input Parameters:
- *	report_id (optional) - specified report id in webcal_report table
- *	offset (optional) - specifies how many days/weeks/months +/- to display.
- *	  For example, if the report type is 1 (today) with offset=5, then
- *	  the report will display 5 days from now.  Should only be specified
- *	  if report_id is specified.  Will be ignored if specified report
- *	  does not have the webcal_report.cal_allow_nav field set to 'Y'.
- *	user (optional) - specifies which user's calendar to use for the
- *	  report.  This will be ignored if the chosen report is tied to
- *	  a specific user.
+ * report_id (optional) - specified report id in webcal_report table
+ * offset (optional) - specifies how many days/weeks/months +/- to display.
+ *   For example, if the report type is 1 (today) with offset=5, then
+ *   the report will display 5 days from now.  Should only be specified
+ *   if report_id is specified.  Will be ignored if specified report
+ *   does not have the webcal_report.cal_allow_nav field set to 'Y'.
+ * user (optional) - specifies which user's calendar to use for the
+ *   report.  This will be ignored if the chosen report is tied to
+ *   a specific user.
  *
  * Security:
- *	If system setting $reports_enabled is set to anything other than
- *	  'Y', then don't allow access to this page.
- *	If webcal_report.cal_is_global is set to 'Y', any user can view
- *	  the report.  If set to 'N', only the creator (set in
- *	  webcal_report.cal_login) can view the report.
- *	If webcal_report.cal_allow_nav is 'Y', then Next and Previous
- *	  links will be presented.  If 'N', then they will not and the
- *	  offset parameter will be ignored.
- *	Public user cannot edit/list reports.
+ * If system setting $reports_enabled is set to anything other than
+ *   'Y', then don't allow access to this page.
+ * If webcal_report.cal_is_global is set to 'Y', any user can view
+ *   the report.  If set to 'N', only the creator (set in
+ *   webcal_report.cal_login) can view the report.
+ * If webcal_report.cal_allow_nav is 'Y', then Next and Previous
+ *   links will be presented.  If 'N', then they will not and the
+ *   offset parameter will be ignored.
+ * Public user cannot edit/list reports.
  *
  */
 
@@ -80,49 +79,59 @@ function event_to_text ( $id, $date, $time, $duration,
       }
     }
   }
-  if ( $login != $user && $access == 'R' && strlen ( $user ) )
+  if ( $login != $user && $access == 'R' && strlen ( $user ) ) {
     $name_str = "(" . translate("Private") . ")";
-  else if ( $login != $event_owner && $access == 'R' &&
-    strlen ( $event_owner ) )
+    $description_str = translate("This event is confidential");
+  } else if ( $login != $event_owner && $access == 'R' &&
+    strlen ( $event_owner ) ) {
     $name_str = "(" . translate("Private") . ")";
-  else if ( $login != $event_owner && strlen ( $event_owner ) ) {
-    $name_str = htmlentities ( $name );
-  } else
-    $name_str = htmlentities ( $name );
+    $description_str = translate("This event is confidential");
+  } else {
+    $name_str = htmlspecialchars ( $name );
+    if ( ! empty ( $allow_html_description ) &&
+      $allow_html_description == 'Y' ) {
+      $str = str_replace ( '&', '&amp;', $description );
+      $description_str = str_replace ( '&amp;amp;', '&amp;', $str );
+      if ( strstr ( $description_str, "<" ) &&
+        strstr ( $description_str, ">" ) ) {
+        // found some HTML
+      } else {
+        // No HTML found.  Add line breaks.
+        $description_str = nl2br ( $description_str );
+      }
+    } else {
+      $description_str = nl2br (
+        activate_urls ( htmlspecialchars ( $description ) ) );
+    }
+  }
 
   $date_str = date_to_str ( $date, "", false );
   $date_full_str = date_to_str ( $date, "", true, false );
 
-  if ( $duration > 0 )
+  if ( $duration > 0 ) {
     $duration_str = $duration . ' ' . translate ( "minutes" );
-  else
-    $duration_str = '';
-
-  if ( $pri == 1 )
-    $pri_str = translate ( "Low" );
-  else if ( $pri == 2 )
-    $pri_str = translate ( "Medium" );
-  else if ( $pri == 3 )
-    $pri_str = translate ( "High" );
-
-  if ( $status == 'W' )
-    $status_str = translate ( "Waiting for approval" );
-  else if ( $status == 'D' )
-    $status_str = translate ( "Deleted" );
-  else if ( $status == 'R' )
-    $status_str = translate ( "Rejected" );
-  else if ( $status == 'A' )
-    $status_str = translate ( "Approved" );
-  else
-    $status_str = translate ( "Unknown" );
-
-  if ( ! empty ( $allow_html_description ) &&
-    $allow_html_description == 'Y' ) {
-    $str = str_replace ( '&', '&amp;', $description );
-    $description_str = str_replace ( '&amp;amp;', '&amp', $str );
   } else {
-    $description_str = nl2br (
-      activate_urls ( htmlentities ( $description ) ) );
+    $duration_str = '';
+  }
+
+  if ( $pri == 1 ) {
+    $pri_str = translate ( "Low" );
+  } else if ( $pri == 2 ) {
+    $pri_str = translate ( "Medium" );
+  } else if ( $pri == 3 ) {
+    $pri_str = translate ( "High" );
+  }
+
+  if ( $status == 'W' ) {
+    $status_str = translate ( "Waiting for approval" );
+  } else if ( $status == 'D' ) {
+    $status_str = translate ( "Deleted" );
+  } else if ( $status == 'R' ) {
+    $status_str = translate ( "Rejected" );
+  } else if ( $status == 'A' ) {
+    $status_str = translate ( "Approved" );
+  } else {
+    $status_str = translate ( "Unknown" );
   }
 
   $href_str = "view_entry.php?id=$id";
@@ -171,8 +180,9 @@ if ( $is_admin && ! empty ( $public ) && $public_access == "Y" ) {
 
 $report_id = getIntValue ( "report_id", true );
 $offset = getIntValue ( "offset", true );
-if ( empty ( $offset ) )
+if ( empty ( $offset ) ) {
   $offset = 0;
+}
 
 // If no report id is specified, then generate a list of reports for
 // the user to select from.
@@ -207,8 +217,11 @@ if ( empty ( $error ) && empty ( $report_id ) ) {
   $list .= "<ul>\n";
   if ( $res ) {
     while ( $row = dbi_fetch_row ( $res ) ){
+      $rep_name = trim ( $row[1] );
+      if ( empty ( $rep_name ) )
+        $rep_name = translate ( "Unnamed Report" );
       $list .= "<li><a href=\"edit_report.php?report_id=$row[0]\" class=\"nav\">" .
-        $row[1] . "</a></li>\n";
+        $rep_name . "</a></li>\n";
     }
     $list .= "</ul>\n";
     $addurl = $updating_public ? "edit_report.php?public=1" : "edit_report.php";
@@ -244,8 +257,9 @@ if ( empty ( $error ) && empty ( $list ) ) {
         $test_report_user = $row[$i++];
         // If this report type specifies a specific user, then we will
         // use that user rather even if a user was passed in via URL.
-        if ( ! empty ( $test_report_user ) )
+        if ( ! empty ( $test_report_user ) ) {
           $report_user = $test_report_user;
+        }
         $report_allow_nav = $row[$i++];
         $report_cat_id = $row[$i++];
         $report_include_empty = $row[$i++];
@@ -260,8 +274,9 @@ if ( empty ( $error ) && empty ( $list ) ) {
   }
 }
 
-if ( empty ( $report_user ) )
+if ( empty ( $report_user ) ) {
   $report_user = $login;
+}
 //echo "User: $report_user <p>";
 
 // Set default templates (in case there are none in the database for
@@ -299,17 +314,15 @@ if ( empty ( $error ) && empty ( $list ) ) {
   }
 }
 
-?>
-
-<?php
-
 if ( ! empty ( $report_include_header ) && $report_include_header == 'Y' ||
-  ! empty ( $list ) || ! empty ( $error ) )
+  ! empty ( $list ) || ! empty ( $error ) ) {
   print_header();
+}
 
 if ( empty ( $offset ) || empty ( $report_allow_nav ) ||
-  $report_allow_nav != 'Y' )
+  $report_allow_nav != 'Y' ) {
   $offset = 0;
+}
 
 // Set time range based on cal_time_range field.
 if ( empty ( $report_time_range ) ) {
@@ -320,12 +333,13 @@ if ( empty ( $report_time_range ) ) {
   $start_date = date ( "Ymd", $today + ( $days_offset * $ONE_DAY ) );
   $end_date = $start_date;
 } else if ( $report_time_range >= 10 && $report_time_range < 20 ) {
-  if ( $WEEK_START == 1 )
+  if ( $WEEK_START == 1 ) {
     $wkstart = get_monday_before ( date ( "Y" ), date ( "m" ),
       date ( "d" ) );
-  else
+  } else {
     $wkstart = get_sunday_before ( date ( "Y" ), date ( "m" ),
       date ( "d" ) );
+  }
   //echo "wkstart = " . date("Ymd",$wkstart) . "<br />";
   $week_offset = 11 - $report_time_range + $offset;
   //echo "week_offset=$week_offset <br />";
@@ -333,12 +347,13 @@ if ( empty ( $report_time_range ) ) {
   $end_date = date ( "Ymd", $wkstart + ( $week_offset * 7 * $ONE_DAY ) + 
     ( $ONE_DAY * 6 ) );
 } else if ( $report_time_range >= 20 && $report_time_range < 30 ) {
-  if ( $WEEK_START == 1 )
+  if ( $WEEK_START == 1 ) {
     $wkstart = get_monday_before ( date ( "Y" ), date ( "m" ),
       date ( "d" ) );
-  else
+  } else {
     $wkstart = get_sunday_before ( date ( "Y" ), date ( "m" ),
       date ( "d" ) );
+  }
   //echo "wkstart = " . date("Ymd",$wkstart) . "<br />";
   $week_offset = 21 - $report_time_range + $offset;
   //echo "week_offset=$week_offset <br />";
@@ -361,6 +376,23 @@ if ( empty ( $report_time_range ) ) {
     $thisyear + $year_offset ) );
   $end_date = date ( "Ymd", mktime ( 3, 0, 0, 12, 31,
     $thisyear + $year_offset ) );
+} else if ( $report_time_range >= 50 && $report_time_range < 60 ) {
+  // This series of reports is today + N days
+  switch ( $report_time_range ) {
+    case 50: $x = 14; break;
+    case 51: $x = 30; break;
+    case 52: $x = 60; break;
+    case 53: $x = 90; break;
+    case 54: $x = 180; break;
+    case 55: $x = 365; break;
+    default: echo "Invalid cal_time_range setting for report id $report_id";
+      exit;
+  }
+  $today = mktime ( 0, 0, 0, date ( "m" ), date ( "d" ), date ( "Y" ) );
+  $start = $today + ( $ONE_DAY * $offset * $x );
+  $end = $start + ( $ONE_DAY * $x );
+  $start_date = date ( "Ymd", $start );
+  $end_date = date ( "Ymd", $end );
 } else {
   // Programmer's bug (no translation needed)
   echo "Invalid cal_time_range setting for report id $report_id";
@@ -375,8 +407,9 @@ if ( empty ( $error ) && empty ( $list ) ) {
   $events = read_events ( $report_user, $start_date, $end_date, $cat_id );
 
   $get_unapproved = $DISPLAY_UNAPPROVED == 'Y';
-  if ( $report_user == "__public__" )
+  if ( $report_user == "__public__" ) {
     $get_unapproved = false;
+  }
 
   //echo "User: $report_user <br />\n";
   //echo "Date Range: $start_date - $end_date <br /><br />\n";
@@ -478,11 +511,13 @@ if ( ! empty ( $error ) ) {
     "</h2>\n" . $error;
 } else if ( ! empty ( $list ) ) {
   echo "<h2>";
-  if ( $updating_public )
+  if ( $updating_public ) {
     echo translate($PUBLIC_ACCESS_FULLNAME) . " ";
+  }
   echo translate("Manage Reports");
   echo "</h2>\n" . 
-  "<a title=\"" . translate("Admin") . "\" class=\"nav\" href=\"adminhome.php\">&laquo;&nbsp;" . translate("Admin") . "</a><br /><br />\n" . $list;
+  "<a title=\"" . translate("Admin") . "\" class=\"nav\" href=\"adminhome.php\"> " .
+     "&laquo;&nbsp;" . translate("Admin") . "</a><br /><br />\n" . $list;
 } else {
   if ( $report_include_header == 'Y' ) {
     echo "<h2>" . $report_name . "</h2>\n";
@@ -494,8 +529,9 @@ if ( ! empty ( $error ) ) {
 
 if ( empty ( $error ) && empty ( $list ) ) {
   if ( ! empty ( $report_allow_nav ) && $report_allow_nav == 'Y' ) {
-    if ( empty ( $offset ) )
+    if ( empty ( $offset ) ) {
       $offset = 0;
+    }
     $next = $offset + 1;
     $prev = $offset - 1;
     echo "<br /><br /><a title=\"" .
@@ -508,7 +544,8 @@ if ( empty ( $error ) && empty ( $list ) ) {
       translate ( "Next" ) . "</a><br />\n";
   }
   if ( $report_include_header == 'Y' ) {
-    echo '<br /><br /><a title="' . translate("Printer Friendly") . '" class="nav" href="report.php?report_id=' . $report_id .
+    echo '<br /><br /><a title="' . translate("Printer Friendly") . 
+      '" class="nav" href="report.php?report_id=' . $report_id .
       '&amp;friendly=1' . $u_url . '&amp;offset=' . $offset .
       '" target="cal_printer_friendly" onmouseover="window.status=\'' .
       translate("Generate printer-friendly version") .
@@ -525,4 +562,4 @@ if ( ! empty ( $list ) || $report_include_header == 'Y'
 
 ?>
 </body>
-</html>
\ No newline at end of file
+</html>
